Module models

Model structs

Modules

enums
Enums live here
errors
Error model structs

Structs

AcceptedPaymentMethods
AcceptedPaymentMethods
AchDetails
ACH-specific details about BANK_ACCOUNT type payments with the transfer_type of ACH.
AddGroupToCustomerResponse
This is a model struct for AddGroupToCustomerResponse type
AdditionalRecipientDeprecated
Represents an additional recipient (other than the merchant) receiving a portion of this tender.
Address
Represents a postal address in a country.
AfterpayDetails
Additional details about Afterpay payments.
ApplicationDetails
Details about the application that took the payment.
AppointmentSegment
Defines an appointment segment of a booking.
AuthorizeOAuthParameters
AuthorizeOAuthResponse
This is a model struct for AuthorizeOAuthResponse type.
Availability
Defines an appointment slot that encapsulates the appointment segments, location and starting time available for booking.
BankAccountPaymentDetails
Additional details about BANK_ACCOUNT type payments.
BatchChangeInventoryRequest
This is a model class for BatchChangeInventoryRequest type.
BatchChangeInventoryResponse
This is a model struct for BatchChangeInventoryResponse type.
BatchDeleteCatalogObjectsRequest
This is a model class for BatchDeleteCatalogObjectsRequest type.
BatchDeleteCatalogObjectsResponse
This is a model struct for BatchDeleteCatalogObjectsResponse type.
BatchRetrieveCatalogObjectsRequest
This is a model class for BatchRetrieveCatalogObjectsRequest type.
BatchRetrieveCatalogObjectsResponse
This is a model struct for BatchRetrieveCatalogObjectsResponse type.
BatchRetrieveInventoryChangesRequest
This is a model struct for BatchRetrieveInventoryChangesRequest type.
BatchRetrieveInventoryChangesResponse
This is a model struct for BatchRetrieveInventoryChangesResponse type.
BatchRetrieveInventoryCountsRequest
This is a model struct for BatchRetrieveInventoryCountsRequest type.
BatchRetrieveInventoryCountsResponse
This is a model struct for BatchRetrieveInventoryCountsResponse type.
BatchRetrieveOrdersRequest
This is a model class for BatchRetrieveOrdersRequest type.
BatchRetrieveOrdersResponse
This is a model struct for BatchRetrieveOrdersResponse type.
BatchUpsertCatalogObjectsRequest
This is a model class for BatchUpsertCatalogObjectsRequest type.
BatchUpsertCatalogObjectsResponse
This is a model struct for BatchUpsertCatalogObjectsResponse type.
Booking
Represents a booking as a time-bound service contract for a seller’s staff member to provide a specified service at a given location to a requesting customer in one or more appointment segments.
BookingCreatorDetails
Information about a booking creator.
BookingEventData
This is a model struct for BookingEventData type.
BookingEventObject
This is a model struct for BookingEventObject type.
BookingEventWebhookResponse
This is a model struct for BookingEventWebhookResponse type.
BulkCreateCustomerData
This is a model struct for BulkCreateCustomerData type
BulkCreateCustomersRequest
This is a model struct for BulkCreateCustomersRequest type
BulkCreateCustomersResponse
This is a model struct for BulkCreateCustomersResponse type
BulkCreateTeamMembersRequest
This is a model struct for BulkCreateTeamMembersRequest type.
BulkCreateTeamMembersResponse
This is a model struct for BulkCreateTeamMembersResponse type.
BulkDeleteCustomersRequest
This is a model struct for BulkDeleteCustomersRequest type
BulkDeleteCustomersResponse
This is a model struct for BulkDeleteCustomersResponse type
BulkRetrieveBookingsRequest
This is a model struct for the BulkRetrieveBookingsRequest type.
BulkRetrieveBookingsResponse
This is a model struct for the BulkRetrieveBookingsResponse type.
BulkRetrieveCustomersRequest
This is a model struct for BulkRetrieveCustomersRequest type
BulkRetrieveCustomersResponse
This is a model struct for BulkRetrieveCustomersResponse type
BulkRetrieveTeamMemberBookingProfilesRequest
This is a model struct for the BulkRetrieveTeamMemberBookingProfilesRequest type.
BulkRetrieveTeamMemberBookingProfilesResponse
This is a model struct for the BulkRetrieveTeamMemberBookingProfilesResponse type.
BulkSwapPlanRequest
This is a model struct for the BulkSwapPlanRequest type.
BulkSwapPlanResponse
This is a model struct for the BulkSwapPlanResponse type.
BulkUpdateCustomerData
This is a model struct for BulkUpdateCustomerData type
BulkUpdateCustomersRequest
This is a model struct for BulkUpdateCustomersRequest type
BulkUpdateCustomersResponse
This is a model struct for BulkUpdateCustomersResponse type
BulkUpdateTeamMembersRequest
This is a model struct for BulkUpdateTeamMembersRequest type.
BulkUpdateTeamMembersResponse
This is a model struct for BulkUpdateTeamMembersResponse type.
BulkUpsertCustomerCustomAttributesRequest
Represents a request for the BulkUpsertCustomerCustomAttributes endpoint.
BulkUpsertCustomerCustomAttributesRequestCustomerCustomAttributeUpsertRequest
Represents an individual upsert request in a BulkUpsertCustomerCustomAttributes request.
BulkUpsertCustomerCustomAttributesResponse
Represents a response for the BulkUpsertCustomerCustomAttributes endpoint.
BulkUpsertCustomerCustomAttributesResponseCustomerCustomAttributeUpsertResponse
Represents a response for an individual upsert request in a BulkUpsertCustomerCustomAttributes operation.
BusinessAppointmentSettings
The service appointment settings, including where and how the service is provided.
BusinessBookingProfile
A seller’s business booking profile, including booking policy, appointment settings, etc.
BusinessHours
The hours of operation for a location.
BusinessHoursPeriod
The hours of operation for a location.
BuyNowPayLaterDetails
Additional details about a Buy Now Pay Later payment type.
CalculateOrderRequest
This is a model struct for CalculateOrderRequest type
CalculateOrderResponse
This is a model struct for CalculateOrderResponse type.
CancelBookingRequest
This is a model class for CancelBookingRequest type.
CancelBookingResponse
This is a model struct for CancelBookingResponse type.
CancelInvoiceRequest
This is a model struct for CancelInvoiceRequest type.
CancelInvoiceResponse
This is a model struct for CancelInvoiceResponse type
CancelPaymentByIdempotencyKeyRequest
This is a model struct for CancelPaymentByIdempotencyRequest type.
CancelPaymentByIdempotencyKeyResponse
This is a model struct for CancelPaymentByIdempotencyKeyResponse type.
CancelPaymentResponse
This is a model struct for CancelPaymentResponse type.
CancelSubscriptionResponse
This is a model struct for CancelSubscriptionResponse type.
Card
Represents the payment details of a card to be used for payments.
CardEventData
This is a model struct for CardEventData type.
CardEventObject
This is a model struct for CardEventObject type.
CardEventWebhookResponse
This is a model struct for CardEventWebhookResponse type.
CardPaymentDetails
Reflects the current status of a card payment.
CardPaymentTimeline
The timeline for card payments.
CashAppDetails
Brand-specific details for payments with the brand of CASH_APP.
CashPaymentDetails
Stores details about a cash payment.
CatalogAvailabilityPeriod
Represents a time period of availability.
CatalogCategory
A category to which a CatalogItem instance belongs.
CatalogCustomAttributeDefinition
Contains information defining a custom attribute.
CatalogCustomAttributeDefinitionNumberConfig
Configuration associated with Custom Attribute Definitions of type NUMBER.
CatalogCustomAttributeDefinitionSelectionConfig
Configuration associated with SELECTION-type custom attribute definitions.
CatalogCustomAttributeDefinitionSelectionConfigCustomAttributeSelection
A named selection for this SELECTION-type custom attribute definition.
CatalogCustomAttributeDefinitionStringConfig
Configuration associated with Custom Attribute Definitions of type STRING.
CatalogCustomAttributeValue
An instance of a custom attribute.
CatalogDiscount
A discount applicable to items.
CatalogEcomSeoData
The SEO data for a seller’s Square Online store.
CatalogEventData
This is a model struct for CatalogEventData type.
CatalogIdMapping
A mapping between a temporary client-supplied ID and a permanent server-generated ID.
CatalogImage
An image file to use in Square catalogs.
CatalogInfoResponse
This is a model struct for CatalogInfoResponse type.
CatalogInfoResponseLimits
Limits that apply to the Catalog Info API.
CatalogItem
A CatalogObject instance of the ITEM type, also referred to as an item, in the catalog.
CatalogItemFoodAndBeverageDetails
The food and beverage-specific details of a FOOD_AND_BEV item.
CatalogItemFoodAndBeverageDetailsDietaryPreference
Dietary preferences that can be assigned to an FOOD_AND_BEV item and its ingredients.
CatalogItemModifierListInfo
Options to control the properties of a CatalogModifierList applied to a CatalogItem instance.
CatalogItemOption
A group of variations for a CatalogItem.
CatalogItemOptionForItem
An option that can be assigned to an item.
CatalogItemOptionValue
An enumerated value that can link a CatalogItemVariation to an item option as one of its item option values.
CatalogItemOptionValueForItemVariation
A CatalogItemOptionValue links an item variation to an item option as an item option value.
CatalogItemVariation
An item variation (i.e., product) in the Catalog object model.
CatalogMeasurementUnit
Represents the unit used to measure a CatalogItemVariation and specifies the precision for decimal quantities.
CatalogModifier
A modifier applicable to items at the time of sale.
CatalogModifierList
list of modifiers applicable to items at the time of sale.
CatalogModifierOverride
Options to control how to override the default behavior of the specified modifier.
CatalogObject
The wrapper object for the catalog entries of a given object type.
CatalogObjectBatch
A batch of catalog objects
CatalogObjectCategory
A CatalogObjectCategory describing the category
CatalogPricingRule
Defines how discounts are automatically applied to a set of items that match the pricing rule during the active time period.
CatalogProductSet
Represents a collection of catalog objects for the purpose of applying a PricingRule.
CatalogQuery
A query composed of one or more different types of filters to narrow the scope of targeted objects when calling the SearchCatalogObjects endpoint.
CatalogQueryExact
The query filter to return the search result by exact match of the specified attribute name and value.
CatalogQueryItemVariationsForItemOptionValues
The query filter to return the item variations containing the specified item option value IDs.
CatalogQueryItemsForItemOptions
The query filter to return the items containing the specified item option IDs.
CatalogQueryItemsForModifierList
The query filter to return the items containing the specified modifier list IDs.
CatalogQueryItemsForTax
The query filter to return the items containing the specified tax IDs.
CatalogQueryPrefix
The query filter to return the search result whose named attribute values are prefixed by the specified attribute value.
CatalogQueryRange
The query filter to return the search result whose named attribute values fall between the specified range.
CatalogQuerySet
The query filter to return the search result(s) by exact match of the specified attribute_name and any of the attribute_values.
CatalogQuerySortedAttribute
The query expression to specify the key to sort search results.
CatalogQueryText
The query filter to return the search result whose searchable attribute values contain all of the specified keywords or tokens, independent of the token order or case.
CatalogQuickAmount
Represents a Quick Amount in the Catalog.
CatalogQuickAmountsSettings
A parent Catalog Object model represents a set of Quick Amounts and the settings control the amounts.
CatalogStockConversion
Represents the rule of conversion between a stockable [CatalogItemVariation] and a non-stockable sell-by or receive-by CatalogItemVariation that share the same underlying stock.
CatalogSubscriptionPlan
Describes a subscription plan.
CatalogSubscriptionPlanVariation
Describes a subscription plan variation.
CatalogTax
A tax applicable to an item.
CatalogTimePeriod
Represents a time period - either a single period or a repeating period.
CatalogV1Id
A Square API V1 identifier of an item, including the object ID and its associated location ID.
CatalogVersionUpdatedEventCatalogVersion
This is a model struct for CatalogVersionUpdatedEventCatalogVersion type.
CatalogVersionUpdatedEventObject
This is a model struct for CatalogVersionUpdatedEventObject type.
CatalogVersionUpdatedWebhookResponse
This is a model struct for CatalogVersionUpdatedWebhookResponse type.
CategoryPathToRootNode
A node in the path from a retrieved category to its root node.
ChangeBillingAnchorDateRequest
This is a model struct for the ChangeBillingAnchorDateRequest type.
ChangeBillingAnchorDateResponse
This is a model struct for the ChangeBillingAnchorDateResponse type.
CheckoutLocationSettings
CheckoutLocationSettingsBranding
CheckoutLocationSettingsCoupons
CheckoutLocationSettingsPolicy
CheckoutLocationSettingsTipping
CheckoutMerchantSettings
CheckoutMerchantSettingsPaymentMethodsAfterpayClearpay
CheckoutMerchantSettingsPaymentMethodsAfterpayClearpayEligibilityRange
CheckoutMerchantSettingsPaymentMethodsPaymentMethod
CheckoutOptions
ClearpayDetails
Details about a Clearpay payment. These details are only populated if the brand is CLEARPAY.
CloneOrderRequest
This is a model struct for CloneOrderRequest type.
CloneOrderResponse
This is a model struct for CloneOrderResponse type.
CompletePaymentRequest
This is a model struct for CompletePaymentRequest type.
CompletePaymentResponse
This is a model struct for CompletePaymentResponse type.
Coordinates
Latitude and longitude coordinates.
CreateBookingRequest
This is a model class for CreateBookingRequest type.
CreateBookingResponse
This is a model struct for CreateBookingResponse type.
CreateCardRequest
This is a model class for CreateCardRequest type.
CreateCardResponse
This is a model struct for CreateCardResponse type.
CreateCatalogImageRequest
This is a model class for CreateCatalogImageRequest type.
CreateCatalogImageResponse
This is a model struct for CreateCatalogImageResponse type.
CreateCustomerCustomAttributeDefinitionRequest
This is a model struct for CreateCustomerCustomAttributeDefinitionRequest type
CreateCustomerCustomAttributeDefinitionResponse
This is a model struct for CreateCustomerCustomAttributeDefinitionResponse type
CreateCustomerGroupRequest
CreateCustomerGroupResponse
CreateCustomerRequest
This is a model struct for CreateCustomerRequest type
CreateCustomerResponse
CreateGiftCardActivityRequest
This is a model struct for CreateGiftCardActivityRequest type
CreateGiftCardActivityResponse
This is a model struct for CreateGiftCardActivityResponse type
CreateGiftCardRequest
This is a model struct for CreateGiftCardRequest type
CreateGiftCardResponse
This is a model struct for CreateGiftCardResponse type
CreateInvoiceAttachmentRequest
This is a model struct for CreateInvoiceAttachmentRequest type.
CreateInvoiceAttachmentResponse
This is a model struct for CreateInvoiceAttachmentResponse type
CreateInvoiceRequest
This is a model struct for CreateInvoiceRequest type
CreateInvoiceResponse
This is a model struct for CreateInvoiceResponse type
CreateJobRequest
This is a model struct for CreateJobRequest type
CreateJobResponse
This is a model struct for CreateJobResponse type
CreateLocationRequest
This is a model struct for CreateLocationRequest type
CreateLocationResponse
This is a model struct for CreateLocationResponse type
CreateOrderRequest
This is a model struct for CreateOrderRequest type
CreateOrderResponse
This is a model struct for CreateOrderResponse type
CreatePaymentLinkRequest
This is a model class for CreatePaymentLinkRequest type.
CreatePaymentLinkResponse
This is a model struct for CreatePaymentLinkResponse type.
CreatePaymentRequest
This is a model class for CreatePaymentRequest type.
CreatePaymentResponse
This is a model struct for CreatePaymentResponse type.
CreateSubscriptionRequest
This is a model class for CreateSubscriptionRequest type.
CreateSubscriptionResponse
This is a model struct for CreateSubscriptionResponse type.
CreateTeamMemberRequest
This is a model struct for CreateTeamMemberRequest type.
CreateTeamMemberResponse
This is a model struct for CreateTeamMemberResponse type.
CreateWebhookSubscriptionRequest
This is a model struct for CreateWebhookSubscriptionRequest type.
CreateWebhookSubscriptionResponse
This is a model struct for CreateWebhookSubscriptionResponse type
CustomAttribute
Represents a custom attribute value.
CustomAttributeDefinition
Represents a definition for custom attribute values.
CustomAttributeFilter
This is a model struct for CustomAttributeFilter type.
CustomField
CustomField : Describes a custom form field to add to the checkout page to collect more information from buyers during checkout. For more information, see Specify checkout options.
Customer
Represents a Square customer profile in the Customer Directory of a Square seller.
CustomerAddressFilter
The customer address filter.
CustomerCustomAttributeFilter
The custom attribute filter.
CustomerCustomAttributeFilterValue
A type-specific filter used in a custom attribute filter to search based on the value of a customer-related custom attribute.
CustomerCustomAttributeFilters
A filter to select customers based on one or more custom attributes. This filter can contain up to 10 custom attribute filters. Each custom attribute filter specifies filtering criteria for a target custom attribute. If multiple custom attribute filters are provided, they are combined as an AND operation.
CustomerDetails
Details about a Square Account payment. The details are only populated if the source_type is SquareAccount.
CustomerEventData
This is a model struct for CustomerEventData type.
CustomerEventObject
This is a model struct for CustomerEventObject type.
CustomerEventWebhookResponse
This is a model struct for CustomerEventWebhookResponse type.
CustomerGroup
Represents a group of customer profiles.
CustomerPreferences
Represents communication preferences for the customer profile.
CustomerSegment
Represents a group of customer profiles that match one or more predefined filter criteria.
CustomerTaxIds
Represents the tax ID associated with a [Customer] profile.
DateTime
Represents a Timestamp or DateTime.
DeleteCatalogObjectResponse
This is a model struct for DeleteCatalogObjectResponse type
DeleteCustomerCustomAttributeDefinitionResponse
This is a model struct for DeleteCustomerCustomAttributeDefinitionResponse type
DeleteCustomerCustomAttributeResponse
Represents the response for deleting a customer custom attribute.
DeleteCustomerGroupResponse
This is a model struct for DeleteCustomerGroupResponse type
DeleteCustomerParameters
This is a model struct for DeleteCustomerParameters (query parameters)
DeleteCustomerResponse
This is a model struct for DeleteCustomerResponse type
DeleteInvoiceAttachmentResponse
This is a model struct for DeleteInvoiceAttachmentResponse type
DeleteInvoiceParameters
This is a model struct for DeleteInvoiceParameters (query parameters)
DeleteInvoiceResponse
This is a model struct for DeleteInvoiceResponse type
DeletePaymentLinkResponse
This is a model struct for DeleteInvoiceResponse type
DeleteSubscriptionActionResponse
This is a model struct for DeleteSubscriptionActionResponse type.
DeleteWebhookSubscriptionResponse
This is a model struct for DeleteWebhookSubscriptionResponse type
DestinationDetails
Details about a refund’s destination.
DestinationDetailsCardRefundDetails
Details about a refund’s card.
DestinationDetailsCashRefundDetails
Stores details about a cash refund. Contains only non-confidential information.
DestinationDetailsExternalRefundDetails
Stores details about an external refund. Contains only non-confidential information.
DeviceDetails
Details about the device that took the payment.
DigitalWalletDetails
Additional details about WALLET type payments.
DisableCardResponse
This is a model struct for DisableCardResponse type
EventTypeMetadata
Contains the metadata of a webhook event type.
ExternalPaymentDetails
Stores details about an external payment.
FilterValue
A filter to select resources based on an exact field value.
FloatNumberRange
Specifies a decimal number range.
GetInvoiceResponse
This is a model struct for GetInvoiceResponse type
GetPaymentRefundResponse
This is a model struct for GetPaymentRefundResponse type
GetPaymentResponse
This is a model struct for GetPaymentResponse type.
GiftCard
Represents a Square gift card.
GiftCardActivity
Represents an action performed on a gift card that affects its state or balance.
GiftCardActivityActivate
Represents details about an ACTIVATE gift card activity type.
GiftCardActivityAdjustDecrement
Represents details about an ADJUST_DECREMENT gift card activity type.
GiftCardActivityAdjustIncrement
Represents details about an ADJUST_INCREMENT gift card activity type.
GiftCardActivityBlock
Represents details about a BLOCK gift card activity type.
GiftCardActivityClearBalance
Represents details about a CLEAR_BALANCE gift card activity type.
GiftCardActivityDeactivate
Represents details about a DEACTIVATE gift card activity type.
GiftCardActivityEventData
This is a model struct for GiftCardActivityEventData type.
GiftCardActivityEventObject
This is a model struct for GiftCardActivityEventObject type.
GiftCardActivityEventWebhookResponse
This is a model struct for GiftCardActivityEventWebhookResponse type.
GiftCardActivityImport
Represents details about an IMPORT gift card activity type.
GiftCardActivityImportReversal
Represents details about an IMPORT_REVERSAL gift card activity type.
GiftCardActivityLoad
Represents details about a LOAD gift card activity type.
GiftCardActivityRedeem
Represents details about a REDEEM gift card activity type.
GiftCardActivityRefund
Represents details about a REFUND gift card activity type.
GiftCardActivityTransferBalanceFrom
Represents details about a TRANSFER_BALANCE_FROM gift card activity type
GiftCardActivityTransferBalanceTo
Represents details about a TRANSFER_BALANCE_TO gift card activity type
GiftCardActivityUnblock
Represents details about a UNBLOCK gift card activity type.
GiftCardActivityUnlinkedActivityRefund
Represents details about a UNLINKED_ACTIVITY_REFUND gift card activity type.
GiftCardEventData
This is a model struct for GiftCardEventData type.
GiftCardEventObject
This is a model struct for GiftCardEventObject type.
GiftCardEventWebhookResponse
This is a model struct for GiftCardEventWebhookResponse type.
InventoryAdjustment
Represents a change in state or quantity of product inventory at a particular time and location.
InventoryAdjustmentGroup
The current calculated inventory counts for the requested object and locations.
InventoryChange
Changes created for the request.
InventoryCount
The current calculated inventory counts for the requested object and locations.
InventoryCountUpdatedEventData
This is a model struct for InventoryCountUpdatedEventData type.
InventoryCountUpdatedEventObject
This is a model struct for InventoryCountUpdatedEventObject type.
InventoryEventWebhookResponse
This is a model struct for InventoryEventWebhookResponse type.
InventoryPhysicalCount
Represents the quantity of an item variation that is physically present at a specific location, verified by a seller or a seller’s employee.
InventoryTransfer
Represents the transfer of a quantity of product inventory at a particular time from one location to another.
Invoice
Stores information about an invoice.
InvoiceAcceptedPaymentMethods
The payment methods that customers can use to pay an invoice on the Square-hosted invoice page.
InvoiceAttachment
Represents a file attached to an invoice
InvoiceCustomField
An additional seller-defined and customer-facing field to include on the invoice.
InvoiceEventData
This is a model struct for InvoiceEventData type.
InvoiceEventObject
This is a model struct for InvoiceEventObject type.
InvoiceEventWebhookResponse
This is a model struct for InvoiceEventWebhookResponse type.
InvoiceFilter
Describes query filters to apply.
InvoicePaymentReminder
Describes a payment request reminder (automatic notification) that Square sends to the customer.
InvoicePaymentRequest
Represents a payment request for an [Invoice].
InvoiceQuery
Describes query criteria for searching invoices.
InvoiceRecipient
Represents a snapshot of customer data.
InvoiceRecipientTaxIds
Represents the tax IDs for an invoice recipient.
InvoiceSort
Identifies the sort field and sort order.
Iso8601Date
ISO 8601 Datetime
ItemVariationLocationOverrides
Price and inventory alerting overrides for a CatalogItemVariation at a specific Location.
Job
Represents a job that can be assigned to team members.
JobAssignment
An object describing a job that a team member is assigned to.
LinkCustomerToGiftCardRequest
This is a model struct for LinkCustomerToGiftCardRequest type
LinkCustomerToGiftCardResponse
This is a model struct for LinkCustomerToGiftCardResponse type
ListBookingsParameters
This is a model struct for ListBookingsParameters (query parameters)
ListBookingsResponse
This is a model struct for ListBookingsResponse type
ListCardsParameters
This is a model struct for ListCardsParameters (query parameters)
ListCardsResponse
This is a model struct for ListCardsResponse type
ListCatalogParameters
This is a model struct for ListCatalogParameters (query parameters)
ListCatalogResponse
This is a model struct for ListCatalogResponse type
ListCustomerCustomAttributeDefinitionsParameters
This is a model struct for ListCustomerCustomAttributeDefinitionsParameters (query parameters)
ListCustomerCustomAttributeDefinitionsResponse
This is a model struct for ListCustomerCustomAttributeDefinitionsResponse type
ListCustomerCustomAttributesParameters
This is a model struct for ListCustomerCustomAttributesParameters (query parameters)
ListCustomerCustomAttributesResponse
This is a model struct for ListCustomerCustomAttributesResponse type
ListCustomerGroupsParameters
This is a model struct for ListCustomerGroupsParameters (query parameters)
ListCustomerGroupsResponse
This is a model struct for ListCustomerGroupsResponse type
ListCustomerSegmentsParameters
This is a model struct for ListCustomerSegmentsParameters (query parameters)
ListCustomerSegmentsResponse
This is a model struct for ListCustomerSegmentsResponse type
ListCustomersParameters
This is a model struct for ListCustomersParameters (query parameters)
ListCustomersResponse
This is a model struct for ListCustomersResponse type
ListGiftCardActivitiesParameters
This is a model struct for ListGiftCardActivitiesParameters (query parameters)
ListGiftCardActivitiesResponse
This is a model struct for ListGiftCardActivitiesResponse type
ListGiftCardsParameters
This is a model struct for ListGiftCardsParameters (query parameters)
ListGiftCardsResponse
This is a model struct for ListGiftCardsResponse type
ListInvoicesParameters
This is a model struct for ListInvoicesParameters (query parameters)
ListInvoicesResponse
This is a model struct for ListInvoicesResponse type
ListJobsParameters
This is a model struct for ListJobsParameters (query parameters)
ListJobsResponse
This is a model struct for ListJobsResponse type
ListLocationBookingProfilesParameters
This is a model struct for ListLocationBookingProfilesParameters (query parameters)
ListLocationBookingProfilesResponse
This is a model struct for ListLocationBookingProfilesResponse type
ListLocationsResponse
This is a model struct for ListLocationsResponse type
ListPaymentLinkResponse
This is a model struct for ListPaymentLinkResponse type
ListPaymentLinksParameters
This is a model struct for ListPaymentLinksParameters (query parameters)
ListPaymentRefundsParameters
This is a model struct for ListPaymentRefundsParameters (query parameters)
ListPaymentRefundsResponse
This is a model struct for ListPaymentRefundsResponse type
ListPaymentsParameters
This is a model struct for ListPaymentsParameters (query parameters)
ListPaymentsResponse
This is a model struct for ListPaymentsResponse type
ListSubscriptionEventsParameters
This is a model struct for ListSubscriptionEventsParameters (query parameters)
ListSubscriptionEventsResponse
This is a model struct for ListSubscriptionEventsResponse type
ListTeamMemberBookingProfilesParameters
This is a model struct for ListTeamMemberBookingProfilesParameters (query parameters)
ListTeamMemberBookingProfilesResponse
This is a model struct for ListTeamMemberBookingProfilesResponse type
ListWebhookEventTypesResponse
This is a model struct for ListWebhookEventTypesResponse type
ListWebhookSubscriptionsParams
This is a model struct for ListWebhookSubscriptionsParams (query parameters)
ListWebhookSubscriptionsResponse
This is a model struct for ListWebhookSubscriptionsResponse type
Location
Represents one of a business’ locations.
LocationBookingProfile
The booking profile of a seller’s location, including the location’s ID and whether the location is enabled for online booking.
LocationEventData
This is a model struct for LocationEventData type.
LocationEventWebhookResponse
This is a model struct for LocationEventWebhookResponse type.
LocationSettingsUpdatedEventData
This is a model struct for LocationSettingsUpdatedEventData type.
LocationSettingsUpdatedEventObject
This is a model struct for LocationSettingsUpdatedEventObject type.
MeasurementUnit
Represents a unit of measurement to use with a quantity, such as ounces or inches.
MeasurementUnitCustom
The information needed to define a custom unit, provided by the seller.
MerchantSettingsUpdatedEventData
This is a model struct for MerchantSettingsUpdatedEventData type.
MerchantSettingsUpdatedEventObject
This is a model struct for MerchantSettingsUpdatedEventObject type.
ModifierLocationOverrides
Location-specific overrides for specified properties of a CatalogModifier object.
Money
Represents an amount of money.
ObtainTokenOAuthRequest
This is a model struct for ObtainTokenOAuthRequest type.
ObtainTokenOAuthResponse
This is a model struct for ObtainTokenOAuthResponse type
OfflinePaymentDetails
Details specific to offline payments.
Order
Contains all information related to a single order to process with Square, including line items that specify the products to purchase.
OrderCreated
This is a model struct for OrderCreated type.
OrderCreatedObject
This is a model struct for OrderCreatedObject type.
OrderEntry
A lightweight description of an order that is returned when returned_entries is true on a [SearchOrdersRequest].
OrderEventWebhookResponse
This is a model struct for OrderEventWebhookResponse type.
OrderFulfillment
This is a model struct for OrderFulfillment type.
OrderFulfillmentDeliveryDetails
Describes delivery details of an order fulfillment.
OrderFulfillmentFulfillmentEntry
This is a model struct for OrderFulfillmentFulfillmentEntry type.
OrderFulfillmentPickupDetails
This is a model struct for OrderFulfillmentPickupDetails type.
OrderFulfillmentPickupDetailsCurbsidePickupDetails
Specific details for curbside pickup.
OrderFulfillmentRecipient
Contains information about the recipient of a fulfillment.
OrderFulfillmentShipmentDetails
Contains the details necessary to fulfill a shipment order.
OrderFulfillmentUpdated
This is a model struct for OrderFulfillmentUpdated type.
OrderFulfillmentUpdatedObject
This is a model struct for OrderFulfillmentUpdatedObject type.
OrderFulfillmentUpdatedUpdate
This is a model struct for OrderFulfillmentUpdatedUpdate type.
OrderLineItem
Represents a line item in an order.
OrderLineItemAppliedDiscount
Represents an applied portion of a discount to a line item in an order.
OrderLineItemAppliedServiceCharge
Model struct for OrderLineItemAppliedServiceCharge type
OrderLineItemAppliedTax
Represents an applied portion of a tax to a line item in an order.
OrderLineItemDiscount
Represents a discount that applies to one or more line items in an order.
OrderLineItemModifier
A [CatalogModifier].
OrderLineItemPricingBlocklists
Describes pricing adjustments that are blocked from manual and automatic application to a line item.
OrderLineItemPricingBlocklistsBlockedDiscount
A discount to block from applying to a line item.
OrderLineItemPricingBlocklistsBlockedTax
A tax to block from applying to a line item.
OrderLineItemTax
Represents a tax that applies to one or more line item in the order.
OrderMoneyAmounts
A collection of various money amounts.
OrderPricingOptions
Pricing options for an order.
OrderQuantityUnit
Contains the measurement unit for a quantity and a precision that specifies the number of digits after the decimal point for decimal quantities.
OrderReturn
The set of line items, service charges, taxes, discounts, tips, and other items being returned in an order.
OrderReturnDiscount
Represents a discount being returned that applies to one or more return line items in an order.
OrderReturnLineItem
The line item being returned in an order.
OrderReturnLineItemModifier
A line item modifier being returned.
OrderReturnServiceCharge
Represents the service charge applied to the original order.
OrderReturnTax
Represents a tax being returned that applies to one or more return line items in an order.
OrderReturnTip
A tip being returned.
OrderReward
Represents a reward that can be applied to an order if the necessary reward tier criteria are met.
OrderRoundingAdjustment
A rounding adjustment of the money being returned.
OrderServiceCharge
Represents a service charge applied to an order.
OrderSource
Represents the origination details of an order.
OrderUpdated
This is a model struct for OrderUpdated type.
OrderUpdatedObject
This is a model struct for OrderUpdatedObject type.
PauseSubscriptionRequest
This is the model struct for the PauseSubscriptionRequest type.
PauseSubscriptionResponse
This is the model struct for the PauseSubscriptionResponse type.
PayOrderRequest
This is a model struct for PayOrderRequest type
PayOrderResponse
This is a model struct for PayOrderResponse type
Payment
Represents a payment processed by the Square API.
PaymentEventData
PaymentEventObject
PaymentEventWebhookResponse
Published when a Payment
PaymentLink
Represents a payment link made using Square.
PaymentLinkRelatedResources
This is a model struct for PaymentLinkRelatedResources type.
PaymentRefund
Represents a refund of a payment made using Square.
Phase
Represents a phase, which can override subscription phases as defined by plan_id
PhaseInput
Represents the arguments used to construct a new phase.
PrePopulatedData
ProcessingFee
Represents the Square processing fee.
PublishInvoiceRequest
This is a model struct for PublishInvoiceRequest type.
PublishInvoiceResponse
This is a model struct for PublishInvoiceResponse type
QuickPay
This is a model class for QuickPay type.
Range
This is a model struct for Range type.
Refund
Represents a refund processed for a Square transaction.
RefundEventData
This is a model struct for RefundEventData type.
RefundEventObject
This is a model struct for RefundEventObject type.
RefundEventWebhookResponse
This is a model struct for RefundEventWebhookResponse type.
RefundPaymentRequest
This is a model struct for RefundPaymentRequest type
RefundPaymentResponse
This is a model struct for RefundPaymentResponse type
RegisterDomainRequest
This is a model struct for RegisterDomainRequest type.
RegisterDomainResponse
This is a model struct for RegisterDomainResponse type
RemoveGroupFromCustomerResponse
This is a model struct for RemoveGroupFromCustomerResponse type
ResumeSubscriptionRequest
This is the model struct for the ResumeSubscriptionRequest type.
ResumeSubscriptionResponse
This is the model struct for the ResumeSubscriptionResponse type.
RetrieveBookingResponse
This is a model struct for RetrieveBookingResponse type.
RetrieveBusinessBookingProfileResponse
This is a model struct for RetrieveBusinessBookingProfileResponse type.
RetrieveCardResponse
This is a model struct for RetrieveCardResponse type
RetrieveCatalogObjectParameters
This is a model struct for RetrieveCatalogObjectParameters (query parameters)
RetrieveCatalogObjectResponse
This is a model struct for RetrieveCatalogObjectResponse type
RetrieveCustomerCustomAttributeDefinitionParameters
This is a model struct for RetrieveCustomerCustomAttributeDefinitionParameters (query parameters)
RetrieveCustomerCustomAttributeDefinitionResponse
This is a model struct for RetrieveCustomerCustomAttributeDefinitionResponse type
RetrieveCustomerCustomAttributeParameters
This is a model struct for RetrieveCustomerCustomAttributeParameters (query parameters)
RetrieveCustomerCustomAttributeResponse
This is a model struct for RetrieveCustomerCustomAttributeResponse type
RetrieveCustomerGroupResponse
This is a model struct for RetrieveCustomerGroupResponse type
RetrieveCustomerResponse
This is a model struct for RetrieveCustomerResponse type
RetrieveCustomerSegmentResponse
This is a model struct for RetrieveCustomerSegmentResponse type
RetrieveGiftCardFromGANRequest
This is a model struct for RetrieveGiftCardFromGANRequest type
RetrieveGiftCardFromGANResponse
This is a model struct for RetrieveGiftCardFromGANResponse type
RetrieveGiftCardFromNonceRequest
This is a model struct for RetrieveGiftCardFromNonceRequest type
RetrieveGiftCardFromNonceResponse
This is a model struct for RetrieveGiftCardFromNonceResponse type
RetrieveGiftCardResponse
This is a model struct for RetrieveGiftCardResponse type
RetrieveInventoryAdjustmentResponse
This is a model struct for RetrieveInventoryAdjustmentResponse type.
RetrieveInventoryCountParams
RetrieveInventoryCountResponse
This is a model struct for RetrieveInventoryCountResponse type.
RetrieveInventoryPhysicalCountResponse
This is a model struct for RetrieveInventoryPhysicalCount type.
RetrieveInventoryTransferResponse
This is a model struct for RetrieveInventoryTransferResponse type.
RetrieveJobResponse
This is a model struct for RetrieveJobResponse type
RetrieveLocationBookingProfileResponse
This is a model struct for RetrieveLocationBookingProfileResponse type.
RetrieveLocationResponse
This is a model struct for RetrieveLocationResponse type
RetrieveLocationSettingsResponse
This is a model struct for RetrieveLocationSettingsResponse type
RetrieveMerchantSettingsResponse
This is a model struct for RetrieveMerchantSettingsResponse type
RetrieveOrderResponse
This is a model struct for RetrieveOrderResponse type.
RetrievePaymentLinkResponse
This is a model struct for RetrievePaymentLinkResponse type
RetrieveSubscriptionParameters
This is a model struct for RetrieveSubscriptionParameters (query parameters)
RetrieveSubscriptionResponse
This is a model struct for the RetrieveSubscriptionResponse type.
RetrieveTeamMemberBookingProfileResponse
This is a model struct for the RetrieveTeamMemberBookingProfileResponse type.
RetrieveTeamMemberResponse
This is a model struct for RetrieveTeamMemberResponse type.
RetrieveTokenStatusResponse
This is a model struct for RetrieveTokenStatusResponse type
RetrieveWageSettingResponse
This is a model struct for RetrieveWageSettingResponse type.
RetrieveWebhookSubscriptionResponse
This is a model struct for RetrieveWebhookSubscriptionResponse type
RevokeTokenOAuthRequest
This is a model struct for RevokeTokenOAuthRequest type.
RevokeTokenOAuthResponse
This is a model struct for RevokeTokenOAuthResponse type
RiskEvaluation
Represents fraud risk information for the associated payment.
SearchAvailabilityFilter
A query filter to search for buyer-accessible availabilities by.
SearchAvailabilityQuery
The query used to search for buyer-accessible availabilities of bookings.
SearchAvailabilityRequest
This is a model struct for SearchAvailabilityRequest type
SearchAvailabilityResponse
This is a model struct for SearchAvailabilityResponse type
SearchCatalogItemsRequest
This is a model struct for SearchCatalogItemsRequest type.
SearchCatalogItemsResponse
This is a model struct for SearchCatalogItemsResponse type
SearchCatalogObjectsRequest
This is a model struct for SearchCatalogObjectsRequest type.
SearchCatalogObjectsResponse
This is a model struct for SearchCatalogObjectsResponse type
SearchCustomerCreationSourceFilter
Filter based on order fulfillment information
SearchCustomersDateTimeFilter
Filter for Customer objects based on whether their CreatedAt timestamps fall within a specified time range.
SearchCustomersFilter
Filtering criteria to use for a SearchCustomers request.
SearchCustomersQuery
Contains query criteria for the search.
SearchCustomersRequest
This is a model struct for SearchCustomersRequest type.
SearchCustomersResponse
This is a model struct for SearchCustomersResponse type
SearchCustomersSort
Sorting criteria for a SearchCustomers request.
SearchCustomersTextFilter
SearchInvoicesRequest
This is a model struct for SearchInvoicesRequest type.
SearchInvoicesResponse
This is a model struct for SearchInvoicesResponse type
SearchOrdersCustomerFilter
A filter based on the order customer_id and any tender customer_id associated with the order.
SearchOrdersDateTimeFilter
Filter for Order objects based on whether their CreatedAt, CLOSED_AT, or UpdatedAt timestamps fall within a specified time range.
SearchOrdersFilter
Filtering criteria to use for a SearchOrders request.
SearchOrdersFulfillmentFilter
Filter based on order fulfillment information
SearchOrdersQuery
Contains query criteria for the search.
SearchOrdersRequest
This is a model struct for SearchOrdersRequest type.
SearchOrdersResponse
This is a model struct for SearchOrdersResponse type
SearchOrdersSort
Sorting criteria for a SearchOrders request.
SearchOrdersSourceFilter
A filter based on order source information.
SearchOrdersStateFilter
Filter by the current order state.
SearchSubscriptionsFilter
Represents a set of query expressions (filters) to narrow the scope of targeted subscriptions returned by the SearchSubscriptions endpoint.
SearchSubscriptionsQuery
Represents a query, consisting of specified query expressions, used to search for subscriptions.
SearchSubscriptionsRequest
This is a model struct for SearchSubscriptionsRequest type.
SearchSubscriptionsResponse
This is a model struct for SearchSubscriptionsResponse type.
SearchTeamMembersFilter
Represents a filter used in a search for TeamMember objects.
SearchTeamMembersQuery
Represents the parameters in a search for TeamMember objects.
SearchTeamMembersRequest
This is a model struct for SearchTeamMembersRequest type.
SearchTeamMembersResponse
This is a model struct for SearchTeamMembersResponse type.
SegmentFilter
A query filter to search for buyer-accessible appointment segments by.
ShippingFee
ShippingFee :
SourceApplication
Provides information about the application used to generate a change.
SquareAccountDetails
Details about a Square Account payment. The details are only populated if the source_type is SquareAccount.
StandardUnitDescription
Contains the name and abbreviation for standard measurement unit.
StandardUnitDescriptionGroup
Group of standard measurement units.
Subscription
Represents a subscription to a subscription plan by a subscriber.
SubscriptionAction
Represents an action as a pending change to a subscription.
SubscriptionEvent
Describes changes to a subscription and the subscription status.
SubscriptionEventData
This is a model struct for SubscriptionEventData type.
SubscriptionEventInfo
Provides information about the subscription event.
SubscriptionEventObject
This is a model struct for SubscriptionEventObject type.
SubscriptionEventWebhookResponse
This is a model struct for SubscriptionEventWebhookResponse type.
SubscriptionPhase
Describes a phase in a subscription plan.
SubscriptionPricing
Describes the pricing for the subscription.
SubscriptionSource
The origination details of the subscription.
SubscriptionTestResult
/// Subscription test result details.
SwapPlanRequest
This is a model struct for the SwapPlanRequest type.
SwapPlanResponse
This is a model struct for the SwapPlanResponse type.
TaxIds
Identifiers for the location used by various governments for tax purposes.
TeamMember
A record representing an individual team member for a business.
TeamMemberAssignedLocations
A record representing an individual team member for a business.
TeamMemberBookingProfile
The booking profile of a seller’s team member, including the team member’s ID, display name, description and whether the team member can be booked as a service provider.
TeamMemberEventData
This is a model struct for TeamMemberEventData type.
TeamMemberEventObject
This is a model struct for TeamMemberEventObject type.
TeamMemberEventWebhookResponse
This is a model struct for TeamMemberEventWebhookResponse type.
Tender
Represents a tender (i.e., a method of payment) used in a Square transaction.
TenderBankAccountDetails
Represents the details of a tender with type BANK_ACCOUNT.
TenderBuyNowPayLaterDetails
Represents the details of a tender with type BUY_NOW_PAY_LATER.
TenderCardDetails
Represents additional details of a tender with type CARD or SQUARE_GIFT_CARD
TenderCashDetails
Represents the details of a tender with type CASH.
TenderSquareAccountDetails
Represents the details of a tender with type SquareAccount.
TestWebhookSubscriptionRequest
This is a model struct for TestWebhookSubscriptionRequest type.
TestWebhookSubscriptionResponse
This is a model struct for TestWebhookSubscriptionResponse type
TimeRange
Represents a generic time range.
TransactionDeprecated
Represents a transaction processed with Square, either with the Connect API or with Square Point of Sale.
UnlinkCustomerFromGiftCardRequest
This is a model struct for UnlinkCustomerFromGiftCardRequest type
UnlinkCustomerFromGiftCardResponse
This is a model struct for UnlinkCustomerFromGiftCardResponse type
UpdateBookingRequest
This is a model class for UpdateBookingRequest type.
UpdateBookingResponse
This is a model struct for UpdateBookingResponse type.
UpdateCatalogImageRequest
This is a model struct for UpdateCatalogImageRequest type.
UpdateCatalogImageResponse
This is a model struct for UpdateCatalogImageResponse type.
UpdateCustomerCustomAttributeDefinitionRequest
This is a model struct for UpdateCustomerCustomAttributeDefinitionRequest type
UpdateCustomerCustomAttributeDefinitionResponse
This is a model struct for UpdateCustomerCustomAttributeDefinitionResponse type
UpdateCustomerGroupRequest
This is a model struct for UpdateCustomerGroupRequest type.
UpdateCustomerGroupResponse
This is a model struct for UpdateCustomerGroupResponse type.
UpdateCustomerRequest
This is a model struct for UpdateCustomerRequest type.
UpdateCustomerResponse
This is a model struct for UpdateCustomerResponse type.
UpdateInvoiceRequest
This is a model struct for UpdateInvoiceRequest type.
UpdateInvoiceResponse
This is a model struct for UpdateInvoiceResponse type.
UpdateItemModifierListsRequest
This is a model struct for UpdateItemModifierListsRequest type.
UpdateItemModifierListsResponse
This is a model struct for UpdateItemModifierListsResponse type.
UpdateItemTaxesRequest
This is a model struct for UpdateItemTaxesRequest type.
UpdateItemTaxesResponse
This is a model struct for UpdateItemTaxesResponse type.
UpdateJobRequest
This is a model struct for UpdateJobRequest type
UpdateJobResponse
This is a model struct for UpdateJobResponse type
UpdateLocationRequest
This is a model struct for the UpdateLocationRequest type
UpdateLocationResponse
This is a model struct for UpdateLocationResponse type
UpdateLocationSettingsRequest
This is a model struct for UpdateLocationSettingsRequest type.
UpdateLocationSettingsResponse
This is a model struct for UpdateLocationSettingsResponse type
UpdateMerchantSettingsRequest
This is a model struct for UpdateMerchantSettingsRequest type.
UpdateMerchantSettingsResponse
This is a model struct for UpdateMerchantSettingsResponse type
UpdateOrderRequest
This is a model struct for UpdateOrderRequest type.
UpdateOrderResponse
This is a model struct for UpdateOrderResponse type.
UpdatePaymentLinkRequest
This is a model struct for UpdatePaymentLinkRequest type.
UpdatePaymentLinkResponse
This is a model struct for UpdatePaymentLinkResponse type
UpdatePaymentRequest
This is a model struct for UpdatePaymentRequest type.
UpdatePaymentResponse
This is a model struct for UpdatePaymentResponse type.
UpdateSubscriptionRequest
This is a model struct for UpdateSubscriptionRequest type.
UpdateSubscriptionResponse
This is a model struct for UpdateSubscriptionResponse type.
UpdateTeamMemberRequest
This is a model struct for UpdateTeamMemberRequest type.
UpdateTeamMemberResponse
This is a model struct for UpdateTeamMemberResponse type.
UpdateWageSettingRequest
This is a model struct for UpdateWageSettingRequest type.
UpdateWageSettingResponse
This is a model struct for UpdateWageSettingResponse type.
UpdateWebhookSubscriptionRequest
This is a model struct for UpdateWebhookSubscriptionRequest type.
UpdateWebhookSubscriptionResponse
This is a model struct for UpdateWebhookSubscriptionResponse type
UpdateWebhookSubscriptionSignatureKeyRequest
This is a model struct for UpdateWebhookSubscriptionSignatureKeyRequest type.
UpdateWebhookSubscriptionSignatureKeyResponse
This is a model struct for UpdateWebhookSubscriptionSignatureKeyResponse type
UpsertCatalogObjectRequest
This is a model struct for UpsertCatalogObjectRequest type.
UpsertCatalogObjectResponse
This is a model struct for UpsertCatalogObjectResponse type.
UpsertCustomerCustomAttributeRequest
Represents the request body for the UpsertCustomerCustomAttribute endpoint.
UpsertCustomerCustomAttributeResponse
Represents the response for the UpsertCustomerCustomAttribute endpoint.
WageSetting
An object representing a team member’s wage information.
WebhookSubscription
Represents the details of a webhook subscription, including notification URL, event types, and signature key.