Module enums

Enums live here

Enums

AchDetailsAccountType
A type of bank account performing a transfer for payment.
ApplicationDetailsExternalSquareProduct
A list of products to return to external callers.
ArchivedState
An enum type of catalog item archived state.
BankAccountPaymentDetailsAccountOwnershipType
An ownership type of a bank account performing a transfer for payment.
BankAccountPaymentDetailsTransferType
A type of bank transfer
BookingBookingSource
The type of a booking booking
BookingCreatorDetailsCreatorType
The type of [Booking] creator
BookingStatus
The status of a booking
BookingWebhookEventType
The type of booking event coming from the webhook
BusinessAppointmentSettingsAlignmentTime
The time unit of the service duration for bookings.
BusinessAppointmentSettingsBookingLocationType
The location type of a business, specific to appointments
BusinessAppointmentSettingsCancellationPolicy
The cancellation policy adopted by the seller.
BusinessAppointmentSettingsMaxAppointmentsPerDayLimitType
Indicates whether the daily appointment limit applies to team members or to business locations.
BusinessBookingProfileBookingPolicy
The policy for the seller to automatically accept booking requests (AcceptAll) or not (RequiresAcceptance).
BusinessBookingProfileCustomerTimezoneChoice
The choice of customer’s time zone information of a booking
CardBrand
Indicates a card’s brand, such as VISA or MASTERCARD.
CardCoBrand
Indicates a card’s co-brand, such as AFTERPAY or CLEARPAY.
CardPaymentDetailsAvsStatus
Status code returned from the Address Verification System (AVS) check.
CardPaymentDetailsCvvStatus
Status code returned from the Card Verification Value (CVV) check.
CardPaymentDetailsEntryMethod
Method used to enter a card’s details for payment.
CardPaymentDetailsStatus
Card payment state.
CardPaymentDetailsVerificationMethod
Method to verify cardholder’s identity.
CardPaymentDetailsVerificationResult
Results of cardholder verification.
CardPrepaidType
Indicates a card’s prepaid type, such as NOT_PREPAID or PREPAID.
CardSquareProduct
Model for CardSquareProduct enum
CardType
Indicates a card’s type, such as CREDIT or DEBIT.
CardWebhookEventType
The type of card event coming from the webhook
CatalogCategoryType
Indicates the type of catalog category.
CatalogCustomAttributeDefinitionAppVisibility
Defines the visibility of a custom attribute to applications other than their creating application.
CatalogCustomAttributeDefinitionSellerVisibility
Defines the visibility of a custom attribute to sellers in Square client applications, Square APIs or in Square UIs (including Square Point of Sale applications and Square Dashboard).
CatalogCustomAttributeDefinitionType
Defines the possible types for a custom attribute.
CatalogDiscountModifyTaxBasis
Indicates whether this discount should reduce the price used to calculate tax.
CatalogDiscountType
How to apply a CatalogDiscount to a CatalogItem.
CatalogItemFoodAndBeverageDetailsDietaryPreferenceStandardDietaryPreference
The name of the dietary preference from a standard pre-defined list. This should be null if it’s a custom dietary preference.
CatalogItemFoodAndBeverageDetailsDietaryPreferenceType
The dietary preference type. Supported values include STANDARD and CUSTOM as specified in FoodAndBeverageDetails.DietaryPreferenceType.
CatalogItemFoodAndBeverageDetailsIngredientStandardIngredient
The name of the ingredient from a standard pre-defined list. This should be null if it’s a custom dietary preference.
CatalogItemProductType
The type of a CatalogItem.
CatalogModifierListModifierType
CatalogModifierListSelectionType
Indicates whether a CatalogModifierList supports multiple selections.
CatalogObjectType
Possible types of CatalogObjects returned from the catalog, each containing type-specific properties in the *_data field corresponding to the specfied object type.
CatalogPricingType
Indicates whether the price of a CatalogItemVariation should be entered manually at the time of sale.
CatalogQuickAmountType
Determines the type of a specific Quick Amount.
CatalogQuickAmountsSettingsOption
Determines a seller’s option on Quick Amounts feature.
CatalogWebhookEventType
The type of catalog event coming from the webhook
ChangeTiming
Supported timings when a pending change, as an action, takes place to a subscription.
CheckoutLocationSettingsBrandingButtonShape
CheckoutLocationSettingsBrandingHeaderType
Country
Indicates the country associated with another entity, such as a business.
Currency
Indicates the associated currency for an amount of money.
CustomAttributeDefinitionVisibility
Represents the level of permission required to view a custom attribute definition.
CustomerCreationSource
Indicates the method used to create the customer profile.
CustomerInclusionExclusion
The rule to include or exclude a certain set of values.
CustomerWebhookEventType
The type of customer event coming from the webhook
DayOfWeek
Indicates the specific day of the week.
DelayAction
The action to be applied to the payment when the delay_duration has elapsed. The action must be CANCEL or COMPLETE.
DestinationDetailsExternalRefundDetailsType
The type of external refund the seller paid to the buyer
DestinationType
The destination type for this refund.
DigitalWalletBrand
The brand used for the WALLET payment.
ErrorCategory
Indicates which high-level category of error has occurred during a request to the Connect API.
ErrorCode
Indicates which high-level category of error has occurred during a request to the Connect API.
ExcludeStrategy
Indicates which products matched by a CatalogPricingRule will be excluded if the pricing rule uses an exclude set.
ExternalPaymentType
The type of external payment the seller received.
GiftCardActivityRedeemStatus
Indicates the status of a gift card redemption.
GiftCardActivityType
Indicates the type of the gift card activity.
GiftCardActivityWebhookEventType
The type of gift card activity event coming from the webhook
GiftCardGANSource
Indicates the source that generated the gift card account number (GAN).
GiftCardStatus
Indicates the gift card state.
GiftCardType
Indicates the gift card type.
GiftCardWebhookEventType
The type of gift card event coming from the webhook
GrantType
An enum type of grant type.
InventoryAlertType
Indicates whether Square should alert the merchant when the inventory quantity of a CatalogItemVariation is low.
InventoryChangeType
Indicates how the inventory change is applied.
InventoryState
A type of state for the related quantity of items
InventoryWebhookEventType
The type of inventory event coming from the webhook
InvoiceAutomaticPaymentSource
Indicates the automatic payment method for an invoice payment request.
InvoiceCustomFieldPlacement
Indicates where to render a custom field on the Square-hosted invoice page and in emailed or PDF copies of the invoice.
InvoiceDeliveryMethod
Indicates how Square delivers the [Invoice] to the customer.
InvoicePaymentReminderStatus
The status of a payment request reminder.
InvoiceRequestMethod
InvoiceRequestType
Indicates the type of the payment request.
InvoiceSortField
Indicates the status of an invoice.
InvoiceStatus
Indicates the status of an invoice.
InvoiceWebhookEventType
The type of invoice event coming from the webhook
JobAssignmentPayType
Enumerates the possible pay types that a job can be assigned.
Language
A language in BCP 47 format. For more information, see Location language code.
Locale
Used in OAuth api. The locale to present the permission request form in. Square detects the appropriate locale automatically. Only provide this value if the application can definitively determine the preferred locale.
LocationCapability
The capabilities a location might have.
LocationStatus
A location’s status.
LocationType
A location’s type.
LocationWebhookEventType
The type of location event coming from the webhook
MeasurementUnitArea
Unit of area used to measure a quantity.
MeasurementUnitGeneric
Reserved for API integrations that lack the ability to specify a real measurement unit.
MeasurementUnitLength
The unit of length used to measure a quantity.
MeasurementUnitTime
Unit of time used to measure a quantity (a duration).
MeasurementUnitUnitType
Describes the type of this unit and indicates which field contains the unit information.
MeasurementUnitVolume
The unit of volume used to measure a quantity.
MeasurementUnitWeight
Unit of weight used to measure a quantity.
OAuthPermission
Permissions that the application is requesting.
OauthAuthorizationRevokedEventRevokerType
The type of revoked event type.
OauthWebhookEventType
The type of oauth event coming from the webhook
OnlineCheckoutLocationSettingsEventType
The type of online checkout location settings event coming from the webhook
OnlineCheckoutMerchantSettingsEventType
The type of online checkout merchant settings event coming from the webhook
OrderEventObject
The type of order event data coming from the webhook
OrderFulfillmentDeliveryDetailsScheduleType
The schedule type of the delivery fulfillment.
OrderFulfillmentFulfillmentLineItemApplication
The line_item_application describes what order line items this fulfillment applies to.
OrderFulfillmentPickupDetailsScheduleType
The schedule type of the pickup fulfillment.
OrderFulfillmentState
The current state of this fulfillment.
OrderFulfillmentType
The type of fulfillment.
OrderLineItemDiscountScope
Indicates whether this is a line-item or order-level discount.
OrderLineItemDiscountType
Indicates how the discount is applied to the associated line item or order.
OrderLineItemItemType
Represents the line item type.
OrderLineItemTaxScope
Indicates whether this is a line-item or order-level tax.
OrderLineItemTaxType
Indicates how the tax is applied to the associated line item or order.
OrderServiceChargeCalculationPhase
Represents a phase in the process of calculating order totals.
OrderServiceChargeScope
Model for OrderServiceChargeScope enum
OrderServiceChargeTreatmentType
Model for OrderServiceChargeTreatmentType enum
OrderServiceChargeType
The type of the service charge.
OrderState
The state of the order.
OrderWebhookEventType
The type of order event coming from the webhook
PaymentCapability
Actions that can be performed on a [Payment]
PaymentDelayAction
Actions that can be applied to [Payment]s when the delay_duration has elapsed.
PaymentEventPaymentEventType
PaymentRefundStatus
Indicates a refund’s current status.
PaymentSortField
Indicates a payment’s current status.
PaymentSourceType
Sources from which [Payment]s can be taken.
PaymentStatus
The status of a [Payment]
ProcessingFeeType
The type of fee assessed or adjusted.
Product
Indicates the Square product used to generate an inventory change.
RefundStatus
Indicates a refund’s current status.
RefundWebhookEventType
The type of refund event coming from the webhook
RegisterDomainResponseStatus
The status of the domain registration.
RiskEvaluationRiskLevel
The risk level associated with a payment.
SearchCatalogItemsRequestStockLevel
Defines supported stock levels of the item inventory.
SearchOrdersSortField
Reserved for API integrations that lack the ability to specify a real measurement unit.
SortCustomersField
Use one or more customer attributes as the sort key to sort searched customer profiles. For example, use the creation date (created_at) of customers or default attributes as the sort key.
SortOrder
The order (e.g., chronological or alphabetical) in which results from a request are returned.
SubscriptionActionType
Supported types of an action as a pending change to a subscription.
SubscriptionCadence
Determines the billing cadence of a [Subscription]
SubscriptionEventInfoCode
Supported info codes of a subscription event.
SubscriptionEventSubscriptionEventType
Supported types of an event occurred to a subscription.
SubscriptionPricingType
Supported types of a subscription pricing.
SubscriptionStatus
Supported subscription statuses.
SubscriptionWebhookEventType
The type of subscription event coming from the webhook
TaxCalculationPhase
When to calculate the taxes due on a cart.
TaxInclusionType
Whether to the tax amount should be additional to or included in the CatalogItem price.
TeamMemberAssignedLocationsAssignmentType
Enumerates the possible assignment types that the team member can have.
TeamMemberStatus
Enumerates the possible statuses the team member can have within a business.
TeamMemberWebhookEventType
The type of team member event coming from the webhook
TenderBankAccountDetailsStatus
The bank account payment’s current state.
TenderBuyNowPayLaterDetailsBrand
The Buy Now Pay Later brand.
TenderBuyNowPayLaterDetailsStatus
Model for TenderBuyNowPayLaterDetailsStatus enum.
TenderCardDetailsEntryMethod
Indicates the method used to enter the card’s details.
TenderCardDetailsStatus
Indicates the card transaction’s current status.
TenderSquareAccountDetailsStatus
Model for TenderSquareAccountDetailsStatus enum.
TenderType
Indicates a tender’s type.
Timezone
An IANA time zone identifier for a time zone.
TransactionProduct
Indicates the Square product used to process a transaction.
WebhookEventType
The types of webhook events