Struct BulkSwapPlanRequest

pub struct BulkSwapPlanRequest {
    pub new_plan_variation_id: String,
    pub old_plan_variation_id: String,
    pub location_id: String,
}
This is a model struct for the BulkSwapPlanRequest type.

Fields

new_plan_variation_id: String

The ID of the new subscription plan.

old_plan_variation_id: String

The ID of the plan variation whose subscriptions should be swapped. Active subscriptions using this plan variation will be subscribed to the new plan variation on their next billing day.

location_id: String

The ID of the location to associate with the swapped subscriptions.