pub struct CashAppDetails {
pub buyer_full_name: Option<String>,
pub buyer_country_code: Option<Country>,
pub buyer_cashtag: Option<String>,
}Expand description
Brand-specific details for payments with the brand of CASH_APP.
Fields
buyer_full_name: Option<String>The name of the Cash App account holder.
buyer_country_code: Option<Country>The country of the Cash App account holder, in ISO 3166-1-alpha-2 format. Min Length 2, Max Length 2
buyer_cashtag: Option<String>Read only $Cashtag of the Cash App account holder.