Struct ListJobsParameters

pub struct ListJobsParameters {
    pub cursor: Option<String>,
}
This is a model struct for ListJobsParameters (query parameters)

Fields

cursor: Option<String>

The pagination cursor returned by the previous call to this endpoint. Provide this cursor to retrieve the next page of results for your original request.

Implementations

Source

impl ListJobsParameters

pub fn to_query_string(&self) -> String

Converts the struct to a query string.