pub struct OrderCreated {
pub order_id: String,
pub version: Option<i32>,
pub location_id: String,
pub state: OrderState,
pub created_at: DateTime,
}Expand description
This is a model struct for OrderCreated type.
Fields
order_id: StringThe order’s unique ID.
version: Option<i32>The version number, which is incremented each time an update is committed to the order. Orders that were not created through the API do not include a version number and therefore cannot be updated.
location_id: StringThe ID of the seller location that this order is associated with.
state: OrderStateThe state of the order.
created_at: DateTimeRead only The timestamp of when the event was created, in RFC 3339 format. Examples for January 25th, 2020 6:25:34pm Pacific Standard Time: UTC: 2020-01-26T02:25:34Z Pacific Standard Time with UTC offset: 2020-01-25T18:25:34-08:00