pub struct OrderEntry {
pub order_id: Option<String>,
pub version: Option<i32>,
pub location_id: Option<String>,
}Expand description
A lightweight description of an order that is returned when returned_entries is
true on a [SearchOrdersRequest].
Fields
order_id: Option<String>The ID of the order.
version: Option<i32>Read only The version number, which is incremented each time an update is committed to the order. Orders that were not created through the API do not include a version number and therefore cannot be updated.
location_id: Option<String>The location ID the order belongs to.