pub struct Range {
pub min: Option<String>,
pub max: Option<String>,
}Expand description
This is a model struct for Range type.
Fields
min: Option<String>The lower bound of the number range. At least one of min or max must be specified. If unspecified, the results will have no minimum value.
max: Option<String>The upper bound of the number range. At least one of min or max must be specified. If unspecified, the results will have no maximum value.