pub struct SubscriptionTestResult {
pub id: Option<String>,
pub status_code: Option<i32>,
pub payload: Option<WebhookEventType>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
/// Subscription test result details.
Fields
id: Option<String>Read only A Square-generated unique ID for the subscription test result.
Max Length: 64
status_code: Option<i32>The status code returned by the subscription notification URL.
payload: Option<WebhookEventType>An object containing the payload of the test event.
For example, a payment.created event.
created_at: Option<DateTime>The timestamp of when the subscription was created, in RFC 3339 format.
Examples for January 25th, 2020 6:25:34pm Pacific Standard Time:
- UTC: 2020-01-26T02:25:34Z
- Pacific Standard Time with UTC offset: 2020-01-25T18:25:34-08:00
updated_at: Option<DateTime>The timestamp of when the subscription was updated, in RFC 3339 format.
Because a subscription test result is unique, this field is the same as the created_at field.
Examples for January 25th, 2020 6:25:34pm Pacific Standard Time:
- UTC: 2020-01-26T02:25:34Z
- Pacific Standard Time with UTC offset: 2020-01-25T18:25:34-08:00