pub struct TeamMemberEventWebhookResponse {
pub merchant_id: String,
pub location_id: Option<String>,
pub type: TeamMemberWebhookEventType,
pub event_id: String,
pub created_at: DateTime,
pub data: TeamMemberEventData,
}Expand description
This is a model struct for TeamMemberEventWebhookResponse type.
Fields
merchant_id: StringThe ID of the target seller associated with the event.
location_id: Option<String>The location id.
type: TeamMemberWebhookEventTypeThe type of this event.
event_id: StringA unique ID for the event.
created_at: DateTimeRead only The timestamp of when the event was created, in RFC 3339 format. Examples for January 25th, 2020 6:25:34pm Pacific Standard Time: UTC: 2020-01-26T02:25:34Z Pacific Standard Time with UTC offset: 2020-01-25T18:25:34-08:00
data: TeamMemberEventDataThe data associated with the event.