pub struct WebhookSubscription {
pub id: Option<String>,
pub name: Option<String>,
pub enabled: Option<bool>,
pub event_types: Option<Vec<WebhookEventType>>,
pub notification_url: Option<String>,
pub api_version: Option<String>,
pub signature_key: Option<String>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
}Expand description
Represents the details of a webhook subscription, including notification URL, event types, and signature key.
Fields
id: Option<String>Read only A Square-generated unique ID for the subscription.
Max Length: 64
name: Option<String>The name of this subscription.
Max Length: 64
enabled: Option<bool>Indicates whether the subscription is enabled (true) or not (false).
event_types: Option<Vec<WebhookEventType>>The event types associated with this subscription.
notification_url: Option<String>The URL to which webhooks are sent.
api_version: Option<String>The API version of the subscription.
This field is optional for CreateWebhookSubscription. The value defaults to the API version used by the application.
signature_key: Option<String>The Square-generated signature key used to validate the origin of the webhook event.
created_at: Option<DateTime>The timestamp of when the subscription was created, in RFC 3339 format.
Examples for January 25th, 2020 6:25:34pm Pacific Standard Time:
- UTC: 2020-01-26T02:25:34Z
- Pacific Standard Time with UTC offset: 2020-01-25T18:25:34-08:00
updated_at: Option<DateTime>The timestamp of when the subscription was last updated, in RFC 3339 format.
Examples for January 25th, 2020 6:25:34pm Pacific Standard Time:
- UTC: 2020-01-26T02:25:34Z
- Pacific Standard Time with UTC offset: 2020-01-25T18:25:34-08:00