Model structs
Modules
Structs
- Accepted
Payment Methods - AcceptedPaymentMethods
- AchDetails
- ACH-specific details about
BANK_ACCOUNTtype payments with thetransfer_typeofACH. - AddGroup
ToCustomer Response - This is a model struct for AddGroupToCustomerResponse type
- Additional
Recipient Deprecated - Represents an additional recipient (other than the merchant) receiving a portion of this tender.
- Address
- Represents a postal address in a country.
- Afterpay
Details - Additional details about Afterpay payments.
- Application
Details - Details about the application that took the payment.
- Appointment
Segment - Defines an appointment segment of a booking.
- AuthorizeO
Auth Parameters - AuthorizeO
Auth Response - This is a model struct for AuthorizeOAuthResponse type.
- Availability
- Defines an appointment slot that encapsulates the appointment segments, location and starting time available for booking.
- Bank
Account Payment Details - Additional details about BANK_ACCOUNT type payments.
- Batch
Change Inventory Request - This is a model class for BatchChangeInventoryRequest type.
- Batch
Change Inventory Response - This is a model struct for BatchChangeInventoryResponse type.
- Batch
Delete Catalog Objects Request - This is a model class for BatchDeleteCatalogObjectsRequest type.
- Batch
Delete Catalog Objects Response - This is a model struct for BatchDeleteCatalogObjectsResponse type.
- Batch
Retrieve Catalog Objects Request - This is a model class for BatchRetrieveCatalogObjectsRequest type.
- Batch
Retrieve Catalog Objects Response - This is a model struct for BatchRetrieveCatalogObjectsResponse type.
- Batch
Retrieve Inventory Changes Request - This is a model struct for BatchRetrieveInventoryChangesRequest type.
- Batch
Retrieve Inventory Changes Response - This is a model struct for BatchRetrieveInventoryChangesResponse type.
- Batch
Retrieve Inventory Counts Request - This is a model struct for BatchRetrieveInventoryCountsRequest type.
- Batch
Retrieve Inventory Counts Response - This is a model struct for BatchRetrieveInventoryCountsResponse type.
- Batch
Retrieve Orders Request - This is a model class for BatchRetrieveOrdersRequest type.
- Batch
Retrieve Orders Response - This is a model struct for BatchRetrieveOrdersResponse type.
- Batch
Upsert Catalog Objects Request - This is a model class for BatchUpsertCatalogObjectsRequest type.
- Batch
Upsert Catalog Objects Response - This is a model struct for BatchUpsertCatalogObjectsResponse type.
- Booking
- Represents a booking as a time-bound service contract for a seller’s staff member to provide a specified service at a given location to a requesting customer in one or more appointment segments.
- Booking
Creator Details - Information about a booking creator.
- Booking
Event Data - This is a model struct for BookingEventData type.
- Booking
Event Object - This is a model struct for BookingEventObject type.
- Booking
Event Webhook Response - This is a model struct for BookingEventWebhookResponse type.
- Bulk
Create Customer Data - This is a model struct for BulkCreateCustomerData type
- Bulk
Create Customers Request - This is a model struct for BulkCreateCustomersRequest type
- Bulk
Create Customers Response - This is a model struct for BulkCreateCustomersResponse type
- Bulk
Create Team Members Request - This is a model struct for BulkCreateTeamMembersRequest type.
- Bulk
Create Team Members Response - This is a model struct for BulkCreateTeamMembersResponse type.
- Bulk
Delete Customers Request - This is a model struct for BulkDeleteCustomersRequest type
- Bulk
Delete Customers Response - This is a model struct for BulkDeleteCustomersResponse type
- Bulk
Retrieve Bookings Request - This is a model struct for the BulkRetrieveBookingsRequest type.
- Bulk
Retrieve Bookings Response - This is a model struct for the BulkRetrieveBookingsResponse type.
- Bulk
Retrieve Customers Request - This is a model struct for BulkRetrieveCustomersRequest type
- Bulk
Retrieve Customers Response - This is a model struct for BulkRetrieveCustomersResponse type
- Bulk
Retrieve Team Member Booking Profiles Request - This is a model struct for the BulkRetrieveTeamMemberBookingProfilesRequest type.
- Bulk
Retrieve Team Member Booking Profiles Response - This is a model struct for the BulkRetrieveTeamMemberBookingProfilesResponse type.
- Bulk
Swap Plan Request - This is a model struct for the BulkSwapPlanRequest type.
- Bulk
Swap Plan Response - This is a model struct for the BulkSwapPlanResponse type.
- Bulk
Update Customer Data - This is a model struct for BulkUpdateCustomerData type
- Bulk
Update Customers Request - This is a model struct for BulkUpdateCustomersRequest type
- Bulk
Update Customers Response - This is a model struct for BulkUpdateCustomersResponse type
- Bulk
Update Team Members Request - This is a model struct for BulkUpdateTeamMembersRequest type.
- Bulk
Update Team Members Response - This is a model struct for BulkUpdateTeamMembersResponse type.
- Bulk
Upsert Customer Custom Attributes Request - Represents a request for the BulkUpsertCustomerCustomAttributes endpoint.
- Bulk
Upsert Customer Custom Attributes Request Customer Custom Attribute Upsert Request - Represents an individual upsert request in a BulkUpsertCustomerCustomAttributes request.
- Bulk
Upsert Customer Custom Attributes Response - Represents a response for the BulkUpsertCustomerCustomAttributes endpoint.
- Bulk
Upsert Customer Custom Attributes Response Customer Custom Attribute Upsert Response - Represents a response for an individual upsert request in a BulkUpsertCustomerCustomAttributes operation.
- Business
Appointment Settings - The service appointment settings, including where and how the service is provided.
- Business
Booking Profile - A seller’s business booking profile, including booking policy, appointment settings, etc.
- Business
Hours - The hours of operation for a location.
- Business
Hours Period - The hours of operation for a location.
- BuyNow
PayLater Details - Additional details about a Buy Now Pay Later payment type.
- Calculate
Order Request - This is a model struct for CalculateOrderRequest type
- Calculate
Order Response - This is a model struct for CalculateOrderResponse type.
- Cancel
Booking Request - This is a model class for CancelBookingRequest type.
- Cancel
Booking Response - This is a model struct for CancelBookingResponse type.
- Cancel
Invoice Request - This is a model struct for CancelInvoiceRequest type.
- Cancel
Invoice Response - This is a model struct for CancelInvoiceResponse type
- Cancel
Payment ByIdempotency KeyRequest - This is a model struct for CancelPaymentByIdempotencyRequest type.
- Cancel
Payment ByIdempotency KeyResponse - This is a model struct for CancelPaymentByIdempotencyKeyResponse type.
- Cancel
Payment Response - This is a model struct for CancelPaymentResponse type.
- Cancel
Subscription Response - This is a model struct for CancelSubscriptionResponse type.
- Card
- Represents the payment details of a card to be used for payments.
- Card
Event Data - This is a model struct for CardEventData type.
- Card
Event Object - This is a model struct for CardEventObject type.
- Card
Event Webhook Response - This is a model struct for CardEventWebhookResponse type.
- Card
Payment Details - Reflects the current status of a card payment.
- Card
Payment Timeline - The timeline for card payments.
- Cash
AppDetails - Brand-specific details for payments with the brand of CASH_APP.
- Cash
Payment Details - Stores details about a cash payment.
- Catalog
Availability Period - Represents a time period of availability.
- Catalog
Category - A category to which a
CatalogIteminstance belongs. - Catalog
Custom Attribute Definition - Contains information defining a custom attribute.
- Catalog
Custom Attribute Definition Number Config - Configuration associated with Custom Attribute Definitions of type
NUMBER. - Catalog
Custom Attribute Definition Selection Config - Configuration associated with
SELECTION-type custom attribute definitions. - Catalog
Custom Attribute Definition Selection Config Custom Attribute Selection - A named selection for this
SELECTION-type custom attribute definition. - Catalog
Custom Attribute Definition String Config - Configuration associated with Custom Attribute Definitions of type
STRING. - Catalog
Custom Attribute Value - An instance of a custom attribute.
- Catalog
Discount - A discount applicable to items.
- Catalog
Ecom SeoData - The SEO data for a seller’s Square Online store.
- Catalog
Event Data - This is a model struct for CatalogEventData type.
- Catalog
IdMapping - A mapping between a temporary client-supplied ID and a permanent server-generated ID.
- Catalog
Image - An image file to use in Square catalogs.
- Catalog
Info Response - This is a model struct for CatalogInfoResponse type.
- Catalog
Info Response Limits - Limits that apply to the Catalog Info API.
- Catalog
Item - A CatalogObject instance of the
ITEMtype, also referred to as an item, in the catalog. - Catalog
Item Food AndBeverage Details - The food and beverage-specific details of a FOOD_AND_BEV item.
- Catalog
Item Food AndBeverage Details Dietary Preference - Dietary preferences that can be assigned to an FOOD_AND_BEV item and its ingredients.
- Catalog
Item Modifier List Info - Options to control the properties of a
CatalogModifierListapplied to aCatalogIteminstance. - Catalog
Item Option - A group of variations for a
CatalogItem. - Catalog
Item Option ForItem - An option that can be assigned to an item.
- Catalog
Item Option Value - An enumerated value that can link a
CatalogItemVariationto an item option as one of its item option values. - Catalog
Item Option Value ForItem Variation - A
CatalogItemOptionValuelinks an item variation to an item option as an item option value. - Catalog
Item Variation - An item variation (i.e., product) in the Catalog object model.
- Catalog
Measurement Unit - Represents the unit used to measure a
CatalogItemVariationand specifies the precision for decimal quantities. - Catalog
Modifier - A modifier applicable to items at the time of sale.
- Catalog
Modifier List - list of modifiers applicable to items at the time of sale.
- Catalog
Modifier Override - Options to control how to override the default behavior of the specified modifier.
- Catalog
Object - The wrapper object for the catalog entries of a given object type.
- Catalog
Object Batch - A batch of catalog objects
- Catalog
Object Category - A CatalogObjectCategory describing the category
- Catalog
Pricing Rule - Defines how discounts are automatically applied to a set of items that match the pricing rule during the active time period.
- Catalog
Product Set - Represents a collection of catalog objects for the purpose of applying a
PricingRule. - Catalog
Query - A query composed of one or more different types of filters to narrow the scope of targeted
objects when calling the
SearchCatalogObjectsendpoint. - Catalog
Query Exact - The query filter to return the search result by exact match of the specified attribute name and value.
- Catalog
Query Item Variations ForItem Option Values - The query filter to return the item variations containing the specified item option value IDs.
- Catalog
Query Items ForItem Options - The query filter to return the items containing the specified item option IDs.
- Catalog
Query Items ForModifier List - The query filter to return the items containing the specified modifier list IDs.
- Catalog
Query Items ForTax - The query filter to return the items containing the specified tax IDs.
- Catalog
Query Prefix - The query filter to return the search result whose named attribute values are prefixed by the specified attribute value.
- Catalog
Query Range - The query filter to return the search result whose named attribute values fall between the specified range.
- Catalog
Query Set - The query filter to return the search result(s) by exact match of the specified
attribute_nameand any of theattribute_values. - Catalog
Query Sorted Attribute - The query expression to specify the key to sort search results.
- Catalog
Query Text - The query filter to return the search result whose searchable attribute values contain all of the specified keywords or tokens, independent of the token order or case.
- Catalog
Quick Amount - Represents a Quick Amount in the Catalog.
- Catalog
Quick Amounts Settings - A parent Catalog Object model represents a set of Quick Amounts and the settings control the amounts.
- Catalog
Stock Conversion - Represents the rule of conversion between a stockable [CatalogItemVariation] and a non-stockable
sell-by or receive-by
CatalogItemVariationthat share the same underlying stock. - Catalog
Subscription Plan - Describes a subscription plan.
- Catalog
Subscription Plan Variation - Describes a subscription plan variation.
- Catalog
Tax - A tax applicable to an item.
- Catalog
Time Period - Represents a time period - either a single period or a repeating period.
- Catalog
V1Id - A Square API V1 identifier of an item, including the object ID and its associated location ID.
- Catalog
Version Updated Event Catalog Version - This is a model struct for CatalogVersionUpdatedEventCatalogVersion type.
- Catalog
Version Updated Event Object - This is a model struct for CatalogVersionUpdatedEventObject type.
- Catalog
Version Updated Webhook Response - This is a model struct for CatalogVersionUpdatedWebhookResponse type.
- Category
Path ToRoot Node - A node in the path from a retrieved category to its root node.
- Change
Billing Anchor Date Request - This is a model struct for the ChangeBillingAnchorDateRequest type.
- Change
Billing Anchor Date Response - This is a model struct for the ChangeBillingAnchorDateResponse type.
- Checkout
Location Settings - Checkout
Location Settings Branding - Checkout
Location Settings Coupons - Checkout
Location Settings Policy - Checkout
Location Settings Tipping - Checkout
Merchant Settings - Checkout
Merchant Settings Payment Methods Afterpay Clearpay - Checkout
Merchant Settings Payment Methods Afterpay Clearpay Eligibility Range - Checkout
Merchant Settings Payment Methods Payment Method - Checkout
Options - Clearpay
Details - Details about a Clearpay payment. These details are only populated if the brand is CLEARPAY.
- Clone
Order Request - This is a model struct for CloneOrderRequest type.
- Clone
Order Response - This is a model struct for CloneOrderResponse type.
- Complete
Payment Request - This is a model struct for CompletePaymentRequest type.
- Complete
Payment Response - This is a model struct for CompletePaymentResponse type.
- Coordinates
- Latitude and longitude coordinates.
- Create
Booking Request - This is a model class for CreateBookingRequest type.
- Create
Booking Response - This is a model struct for CreateBookingResponse type.
- Create
Card Request - This is a model class for CreateCardRequest type.
- Create
Card Response - This is a model struct for CreateCardResponse type.
- Create
Catalog Image Request - This is a model class for CreateCatalogImageRequest type.
- Create
Catalog Image Response - This is a model struct for CreateCatalogImageResponse type.
- Create
Customer Custom Attribute Definition Request - This is a model struct for CreateCustomerCustomAttributeDefinitionRequest type
- Create
Customer Custom Attribute Definition Response - This is a model struct for CreateCustomerCustomAttributeDefinitionResponse type
- Create
Customer Group Request - Create
Customer Group Response - Create
Customer Request - This is a model struct for CreateCustomerRequest type
- Create
Customer Response - Create
Gift Card Activity Request - This is a model struct for CreateGiftCardActivityRequest type
- Create
Gift Card Activity Response - This is a model struct for CreateGiftCardActivityResponse type
- Create
Gift Card Request - This is a model struct for CreateGiftCardRequest type
- Create
Gift Card Response - This is a model struct for CreateGiftCardResponse type
- Create
Invoice Attachment Request - This is a model struct for CreateInvoiceAttachmentRequest type.
- Create
Invoice Attachment Response - This is a model struct for CreateInvoiceAttachmentResponse type
- Create
Invoice Request - This is a model struct for CreateInvoiceRequest type
- Create
Invoice Response - This is a model struct for CreateInvoiceResponse type
- Create
JobRequest - This is a model struct for CreateJobRequest type
- Create
JobResponse - This is a model struct for CreateJobResponse type
- Create
Location Request - This is a model struct for CreateLocationRequest type
- Create
Location Response - This is a model struct for CreateLocationResponse type
- Create
Order Request - This is a model struct for CreateOrderRequest type
- Create
Order Response - This is a model struct for CreateOrderResponse type
- Create
Payment Link Request - This is a model class for CreatePaymentLinkRequest type.
- Create
Payment Link Response - This is a model struct for CreatePaymentLinkResponse type.
- Create
Payment Request - This is a model class for CreatePaymentRequest type.
- Create
Payment Response - This is a model struct for CreatePaymentResponse type.
- Create
Subscription Request - This is a model class for CreateSubscriptionRequest type.
- Create
Subscription Response - This is a model struct for CreateSubscriptionResponse type.
- Create
Team Member Request - This is a model struct for CreateTeamMemberRequest type.
- Create
Team Member Response - This is a model struct for CreateTeamMemberResponse type.
- Create
Webhook Subscription Request - This is a model struct for CreateWebhookSubscriptionRequest type.
- Create
Webhook Subscription Response - This is a model struct for CreateWebhookSubscriptionResponse type
- Custom
Attribute - Represents a custom attribute value.
- Custom
Attribute Definition - Represents a definition for custom attribute values.
- Custom
Attribute Filter - This is a model struct for CustomAttributeFilter type.
- Custom
Field - CustomField : Describes a custom form field to add to the checkout page to collect more information from buyers during checkout. For more information, see Specify checkout options.
- Customer
- Represents a Square customer profile in the Customer Directory of a Square seller.
- Customer
Address Filter - The customer address filter.
- Customer
Custom Attribute Filter - The custom attribute filter.
- Customer
Custom Attribute Filter Value - A type-specific filter used in a custom attribute filter to search based on the value of a customer-related custom attribute.
- Customer
Custom Attribute Filters - A filter to select customers based on one or more custom attributes. This filter can contain up to 10 custom attribute filters. Each custom attribute filter specifies filtering criteria for a target custom attribute. If multiple custom attribute filters are provided, they are combined as an AND operation.
- Customer
Details - Details about a Square Account payment. The details are only populated if the source_type is SquareAccount.
- Customer
Event Data - This is a model struct for CustomerEventData type.
- Customer
Event Object - This is a model struct for CustomerEventObject type.
- Customer
Event Webhook Response - This is a model struct for CustomerEventWebhookResponse type.
- Customer
Group - Represents a group of customer profiles.
- Customer
Preferences - Represents communication preferences for the customer profile.
- Customer
Segment - Represents a group of customer profiles that match one or more predefined filter criteria.
- Customer
TaxIds - Represents the tax ID associated with a [Customer] profile.
- Date
Time - Represents a Timestamp or DateTime.
- Delete
Catalog Object Response - This is a model struct for DeleteCatalogObjectResponse type
- Delete
Customer Custom Attribute Definition Response - This is a model struct for DeleteCustomerCustomAttributeDefinitionResponse type
- Delete
Customer Custom Attribute Response - Represents the response for deleting a customer custom attribute.
- Delete
Customer Group Response - This is a model struct for DeleteCustomerGroupResponse type
- Delete
Customer Parameters - This is a model struct for DeleteCustomerParameters (query parameters)
- Delete
Customer Response - This is a model struct for DeleteCustomerResponse type
- Delete
Invoice Attachment Response - This is a model struct for DeleteInvoiceAttachmentResponse type
- Delete
Invoice Parameters - This is a model struct for DeleteInvoiceParameters (query parameters)
- Delete
Invoice Response - This is a model struct for DeleteInvoiceResponse type
- Delete
Payment Link Response - This is a model struct for DeleteInvoiceResponse type
- Delete
Subscription Action Response - This is a model struct for DeleteSubscriptionActionResponse type.
- Delete
Webhook Subscription Response - This is a model struct for DeleteWebhookSubscriptionResponse type
- Destination
Details - Details about a refund’s destination.
- Destination
Details Card Refund Details - Details about a refund’s card.
- Destination
Details Cash Refund Details - Stores details about a cash refund. Contains only non-confidential information.
- Destination
Details External Refund Details - Stores details about an external refund. Contains only non-confidential information.
- Device
Details - Details about the device that took the payment.
- Digital
Wallet Details - Additional details about
WALLETtype payments. - Disable
Card Response - This is a model struct for DisableCardResponse type
- Event
Type Metadata - Contains the metadata of a webhook event type.
- External
Payment Details - Stores details about an external payment.
- Filter
Value - A filter to select resources based on an exact field value.
- Float
Number Range - Specifies a decimal number range.
- GetInvoice
Response - This is a model struct for GetInvoiceResponse type
- GetPayment
Refund Response - This is a model struct for GetPaymentRefundResponse type
- GetPayment
Response - This is a model struct for GetPaymentResponse type.
- Gift
Card - Represents a Square gift card.
- Gift
Card Activity - Represents an action performed on a gift card that affects its state or balance.
- Gift
Card Activity Activate - Represents details about an
ACTIVATEgift card activity type. - Gift
Card Activity Adjust Decrement - Represents details about an
ADJUST_DECREMENTgift card activity type. - Gift
Card Activity Adjust Increment - Represents details about an
ADJUST_INCREMENTgift card activity type. - Gift
Card Activity Block - Represents details about a
BLOCKgift card activity type. - Gift
Card Activity Clear Balance - Represents details about a
CLEAR_BALANCEgift card activity type. - Gift
Card Activity Deactivate - Represents details about a
DEACTIVATEgift card activity type. - Gift
Card Activity Event Data - This is a model struct for GiftCardActivityEventData type.
- Gift
Card Activity Event Object - This is a model struct for GiftCardActivityEventObject type.
- Gift
Card Activity Event Webhook Response - This is a model struct for GiftCardActivityEventWebhookResponse type.
- Gift
Card Activity Import - Represents details about an
IMPORTgift card activity type. - Gift
Card Activity Import Reversal - Represents details about an
IMPORT_REVERSALgift card activity type. - Gift
Card Activity Load - Represents details about a
LOADgift card activity type. - Gift
Card Activity Redeem - Represents details about a
REDEEMgift card activity type. - Gift
Card Activity Refund - Represents details about a
REFUNDgift card activity type. - Gift
Card Activity Transfer Balance From - Represents details about a TRANSFER_BALANCE_FROM gift card activity type
- Gift
Card Activity Transfer Balance To - Represents details about a TRANSFER_BALANCE_TO gift card activity type
- Gift
Card Activity Unblock - Represents details about a
UNBLOCKgift card activity type. - Gift
Card Activity Unlinked Activity Refund - Represents details about a
UNLINKED_ACTIVITY_REFUNDgift card activity type. - Gift
Card Event Data - This is a model struct for GiftCardEventData type.
- Gift
Card Event Object - This is a model struct for GiftCardEventObject type.
- Gift
Card Event Webhook Response - This is a model struct for GiftCardEventWebhookResponse type.
- Inventory
Adjustment - Represents a change in state or quantity of product inventory at a particular time and location.
- Inventory
Adjustment Group - The current calculated inventory counts for the requested object and locations.
- Inventory
Change - Changes created for the request.
- Inventory
Count - The current calculated inventory counts for the requested object and locations.
- Inventory
Count Updated Event Data - This is a model struct for InventoryCountUpdatedEventData type.
- Inventory
Count Updated Event Object - This is a model struct for InventoryCountUpdatedEventObject type.
- Inventory
Event Webhook Response - This is a model struct for InventoryEventWebhookResponse type.
- Inventory
Physical Count - Represents the quantity of an item variation that is physically present at a specific location, verified by a seller or a seller’s employee.
- Inventory
Transfer - Represents the transfer of a quantity of product inventory at a particular time from one location to another.
- Invoice
- Stores information about an invoice.
- Invoice
Accepted Payment Methods - The payment methods that customers can use to pay an invoice on the Square-hosted invoice page.
- Invoice
Attachment - Represents a file attached to an invoice
- Invoice
Custom Field - An additional seller-defined and customer-facing field to include on the invoice.
- Invoice
Event Data - This is a model struct for InvoiceEventData type.
- Invoice
Event Object - This is a model struct for InvoiceEventObject type.
- Invoice
Event Webhook Response - This is a model struct for InvoiceEventWebhookResponse type.
- Invoice
Filter - Describes query filters to apply.
- Invoice
Payment Reminder - Describes a payment request reminder (automatic notification) that Square sends to the customer.
- Invoice
Payment Request - Represents a payment request for an [Invoice].
- Invoice
Query - Describes query criteria for searching invoices.
- Invoice
Recipient - Represents a snapshot of customer data.
- Invoice
Recipient TaxIds - Represents the tax IDs for an invoice recipient.
- Invoice
Sort - Identifies the sort field and sort order.
- Iso8601
Date - ISO 8601 Datetime
- Item
Variation Location Overrides - Price and inventory alerting overrides for a
CatalogItemVariationat a specificLocation. - Job
- Represents a job that can be assigned to team members.
- JobAssignment
- An object describing a job that a team member is assigned to.
- Link
Customer ToGift Card Request - This is a model struct for LinkCustomerToGiftCardRequest type
- Link
Customer ToGift Card Response - This is a model struct for LinkCustomerToGiftCardResponse type
- List
Bookings Parameters - This is a model struct for ListBookingsParameters (query parameters)
- List
Bookings Response - This is a model struct for ListBookingsResponse type
- List
Cards Parameters - This is a model struct for ListCardsParameters (query parameters)
- List
Cards Response - This is a model struct for ListCardsResponse type
- List
Catalog Parameters - This is a model struct for ListCatalogParameters (query parameters)
- List
Catalog Response - This is a model struct for ListCatalogResponse type
- List
Customer Custom Attribute Definitions Parameters - This is a model struct for ListCustomerCustomAttributeDefinitionsParameters (query parameters)
- List
Customer Custom Attribute Definitions Response - This is a model struct for ListCustomerCustomAttributeDefinitionsResponse type
- List
Customer Custom Attributes Parameters - This is a model struct for ListCustomerCustomAttributesParameters (query parameters)
- List
Customer Custom Attributes Response - This is a model struct for ListCustomerCustomAttributesResponse type
- List
Customer Groups Parameters - This is a model struct for ListCustomerGroupsParameters (query parameters)
- List
Customer Groups Response - This is a model struct for ListCustomerGroupsResponse type
- List
Customer Segments Parameters - This is a model struct for ListCustomerSegmentsParameters (query parameters)
- List
Customer Segments Response - This is a model struct for ListCustomerSegmentsResponse type
- List
Customers Parameters - This is a model struct for ListCustomersParameters (query parameters)
- List
Customers Response - This is a model struct for ListCustomersResponse type
- List
Gift Card Activities Parameters - This is a model struct for ListGiftCardActivitiesParameters (query parameters)
- List
Gift Card Activities Response - This is a model struct for ListGiftCardActivitiesResponse type
- List
Gift Cards Parameters - This is a model struct for ListGiftCardsParameters (query parameters)
- List
Gift Cards Response - This is a model struct for ListGiftCardsResponse type
- List
Invoices Parameters - This is a model struct for ListInvoicesParameters (query parameters)
- List
Invoices Response - This is a model struct for ListInvoicesResponse type
- List
Jobs Parameters - This is a model struct for ListJobsParameters (query parameters)
- List
Jobs Response - This is a model struct for ListJobsResponse type
- List
Location Booking Profiles Parameters - This is a model struct for ListLocationBookingProfilesParameters (query parameters)
- List
Location Booking Profiles Response - This is a model struct for ListLocationBookingProfilesResponse type
- List
Locations Response - This is a model struct for ListLocationsResponse type
- List
Payment Link Response - This is a model struct for ListPaymentLinkResponse type
- List
Payment Links Parameters - This is a model struct for ListPaymentLinksParameters (query parameters)
- List
Payment Refunds Parameters - This is a model struct for ListPaymentRefundsParameters (query parameters)
- List
Payment Refunds Response - This is a model struct for ListPaymentRefundsResponse type
- List
Payments Parameters - This is a model struct for ListPaymentsParameters (query parameters)
- List
Payments Response - This is a model struct for ListPaymentsResponse type
- List
Subscription Events Parameters - This is a model struct for ListSubscriptionEventsParameters (query parameters)
- List
Subscription Events Response - This is a model struct for ListSubscriptionEventsResponse type
- List
Team Member Booking Profiles Parameters - This is a model struct for ListTeamMemberBookingProfilesParameters (query parameters)
- List
Team Member Booking Profiles Response - This is a model struct for ListTeamMemberBookingProfilesResponse type
- List
Webhook Event Types Response - This is a model struct for ListWebhookEventTypesResponse type
- List
Webhook Subscriptions Params - This is a model struct for ListWebhookSubscriptionsParams (query parameters)
- List
Webhook Subscriptions Response - This is a model struct for ListWebhookSubscriptionsResponse type
- Location
- Represents one of a business’ locations.
- Location
Booking Profile - The booking profile of a seller’s location, including the location’s ID and whether the location is enabled for online booking.
- Location
Event Data - This is a model struct for LocationEventData type.
- Location
Event Webhook Response - This is a model struct for LocationEventWebhookResponse type.
- Location
Settings Updated Event Data - This is a model struct for LocationSettingsUpdatedEventData type.
- Location
Settings Updated Event Object - This is a model struct for LocationSettingsUpdatedEventObject type.
- Measurement
Unit - Represents a unit of measurement to use with a quantity, such as ounces or inches.
- Measurement
Unit Custom - The information needed to define a custom unit, provided by the seller.
- Merchant
Settings Updated Event Data - This is a model struct for MerchantSettingsUpdatedEventData type.
- Merchant
Settings Updated Event Object - This is a model struct for MerchantSettingsUpdatedEventObject type.
- Modifier
Location Overrides - Location-specific overrides for specified properties of a
CatalogModifierobject. - Money
- Represents an amount of money.
- Obtain
TokenO Auth Request - This is a model struct for ObtainTokenOAuthRequest type.
- Obtain
TokenO Auth Response - This is a model struct for ObtainTokenOAuthResponse type
- Offline
Payment Details - Details specific to offline payments.
- Order
- Contains all information related to a single order to process with Square, including line items that specify the products to purchase.
- Order
Created - This is a model struct for OrderCreated type.
- Order
Created Object - This is a model struct for OrderCreatedObject type.
- Order
Entry - A lightweight description of an order that is returned when
returned_entriesistrueon a [SearchOrdersRequest]. - Order
Event Webhook Response - This is a model struct for OrderEventWebhookResponse type.
- Order
Fulfillment - This is a model struct for OrderFulfillment type.
- Order
Fulfillment Delivery Details - Describes delivery details of an order fulfillment.
- Order
Fulfillment Fulfillment Entry - This is a model struct for OrderFulfillmentFulfillmentEntry type.
- Order
Fulfillment Pickup Details - This is a model struct for OrderFulfillmentPickupDetails type.
- Order
Fulfillment Pickup Details Curbside Pickup Details - Specific details for curbside pickup.
- Order
Fulfillment Recipient - Contains information about the recipient of a fulfillment.
- Order
Fulfillment Shipment Details - Contains the details necessary to fulfill a shipment order.
- Order
Fulfillment Updated - This is a model struct for OrderFulfillmentUpdated type.
- Order
Fulfillment Updated Object - This is a model struct for OrderFulfillmentUpdatedObject type.
- Order
Fulfillment Updated Update - This is a model struct for OrderFulfillmentUpdatedUpdate type.
- Order
Line Item - Represents a line item in an order.
- Order
Line Item Applied Discount - Represents an applied portion of a discount to a line item in an order.
- Order
Line Item Applied Service Charge - Model struct for OrderLineItemAppliedServiceCharge type
- Order
Line Item Applied Tax - Represents an applied portion of a tax to a line item in an order.
- Order
Line Item Discount - Represents a discount that applies to one or more line items in an order.
- Order
Line Item Modifier - A [CatalogModifier].
- Order
Line Item Pricing Blocklists - Describes pricing adjustments that are blocked from manual and automatic application to a line item.
- Order
Line Item Pricing Blocklists Blocked Discount - A discount to block from applying to a line item.
- Order
Line Item Pricing Blocklists Blocked Tax - A tax to block from applying to a line item.
- Order
Line Item Tax - Represents a tax that applies to one or more line item in the order.
- Order
Money Amounts - A collection of various money amounts.
- Order
Pricing Options - Pricing options for an order.
- Order
Quantity Unit - Contains the measurement unit for a quantity and a precision that specifies the number of digits after the decimal point for decimal quantities.
- Order
Return - The set of line items, service charges, taxes, discounts, tips, and other items being returned in an order.
- Order
Return Discount - Represents a discount being returned that applies to one or more return line items in an order.
- Order
Return Line Item - The line item being returned in an order.
- Order
Return Line Item Modifier - A line item modifier being returned.
- Order
Return Service Charge - Represents the service charge applied to the original order.
- Order
Return Tax - Represents a tax being returned that applies to one or more return line items in an order.
- Order
Return Tip - A tip being returned.
- Order
Reward - Represents a reward that can be applied to an order if the necessary reward tier criteria are met.
- Order
Rounding Adjustment - A rounding adjustment of the money being returned.
- Order
Service Charge - Represents a service charge applied to an order.
- Order
Source - Represents the origination details of an order.
- Order
Updated - This is a model struct for OrderUpdated type.
- Order
Updated Object - This is a model struct for OrderUpdatedObject type.
- Pause
Subscription Request - This is the model struct for the PauseSubscriptionRequest type.
- Pause
Subscription Response - This is the model struct for the PauseSubscriptionResponse type.
- PayOrder
Request - This is a model struct for PayOrderRequest type
- PayOrder
Response - This is a model struct for PayOrderResponse type
- Payment
- Represents a payment processed by the Square API.
- Payment
Event Data - Payment
Event Object - Payment
Event Webhook Response - Published when a Payment
- Payment
Link - Represents a payment link made using Square.
- Payment
Link Related Resources - This is a model struct for PaymentLinkRelatedResources type.
- Payment
Refund - Represents a refund of a payment made using Square.
- Phase
- Represents a phase, which can override subscription phases as defined by plan_id
- Phase
Input - Represents the arguments used to construct a new phase.
- PrePopulated
Data - Processing
Fee - Represents the Square processing fee.
- Publish
Invoice Request - This is a model struct for PublishInvoiceRequest type.
- Publish
Invoice Response - This is a model struct for PublishInvoiceResponse type
- Quick
Pay - This is a model class for QuickPay type.
- Range
- This is a model struct for Range type.
- Refund
- Represents a refund processed for a Square transaction.
- Refund
Event Data - This is a model struct for RefundEventData type.
- Refund
Event Object - This is a model struct for RefundEventObject type.
- Refund
Event Webhook Response - This is a model struct for RefundEventWebhookResponse type.
- Refund
Payment Request - This is a model struct for RefundPaymentRequest type
- Refund
Payment Response - This is a model struct for RefundPaymentResponse type
- Register
Domain Request - This is a model struct for RegisterDomainRequest type.
- Register
Domain Response - This is a model struct for RegisterDomainResponse type
- Remove
Group From Customer Response - This is a model struct for RemoveGroupFromCustomerResponse type
- Resume
Subscription Request - This is the model struct for the ResumeSubscriptionRequest type.
- Resume
Subscription Response - This is the model struct for the ResumeSubscriptionResponse type.
- Retrieve
Booking Response - This is a model struct for RetrieveBookingResponse type.
- Retrieve
Business Booking Profile Response - This is a model struct for RetrieveBusinessBookingProfileResponse type.
- Retrieve
Card Response - This is a model struct for RetrieveCardResponse type
- Retrieve
Catalog Object Parameters - This is a model struct for RetrieveCatalogObjectParameters (query parameters)
- Retrieve
Catalog Object Response - This is a model struct for RetrieveCatalogObjectResponse type
- Retrieve
Customer Custom Attribute Definition Parameters - This is a model struct for RetrieveCustomerCustomAttributeDefinitionParameters (query parameters)
- Retrieve
Customer Custom Attribute Definition Response - This is a model struct for RetrieveCustomerCustomAttributeDefinitionResponse type
- Retrieve
Customer Custom Attribute Parameters - This is a model struct for RetrieveCustomerCustomAttributeParameters (query parameters)
- Retrieve
Customer Custom Attribute Response - This is a model struct for RetrieveCustomerCustomAttributeResponse type
- Retrieve
Customer Group Response - This is a model struct for RetrieveCustomerGroupResponse type
- Retrieve
Customer Response - This is a model struct for RetrieveCustomerResponse type
- Retrieve
Customer Segment Response - This is a model struct for RetrieveCustomerSegmentResponse type
- Retrieve
Gift Card FromGAN Request - This is a model struct for RetrieveGiftCardFromGANRequest type
- Retrieve
Gift Card FromGAN Response - This is a model struct for RetrieveGiftCardFromGANResponse type
- Retrieve
Gift Card From Nonce Request - This is a model struct for RetrieveGiftCardFromNonceRequest type
- Retrieve
Gift Card From Nonce Response - This is a model struct for RetrieveGiftCardFromNonceResponse type
- Retrieve
Gift Card Response - This is a model struct for RetrieveGiftCardResponse type
- Retrieve
Inventory Adjustment Response - This is a model struct for RetrieveInventoryAdjustmentResponse type.
- Retrieve
Inventory Count Params - Retrieve
Inventory Count Response - This is a model struct for RetrieveInventoryCountResponse type.
- Retrieve
Inventory Physical Count Response - This is a model struct for RetrieveInventoryPhysicalCount type.
- Retrieve
Inventory Transfer Response - This is a model struct for RetrieveInventoryTransferResponse type.
- Retrieve
JobResponse - This is a model struct for RetrieveJobResponse type
- Retrieve
Location Booking Profile Response - This is a model struct for RetrieveLocationBookingProfileResponse type.
- Retrieve
Location Response - This is a model struct for RetrieveLocationResponse type
- Retrieve
Location Settings Response - This is a model struct for RetrieveLocationSettingsResponse type
- Retrieve
Merchant Settings Response - This is a model struct for RetrieveMerchantSettingsResponse type
- Retrieve
Order Response - This is a model struct for RetrieveOrderResponse type.
- Retrieve
Payment Link Response - This is a model struct for RetrievePaymentLinkResponse type
- Retrieve
Subscription Parameters - This is a model struct for RetrieveSubscriptionParameters (query parameters)
- Retrieve
Subscription Response - This is a model struct for the RetrieveSubscriptionResponse type.
- Retrieve
Team Member Booking Profile Response - This is a model struct for the RetrieveTeamMemberBookingProfileResponse type.
- Retrieve
Team Member Response - This is a model struct for RetrieveTeamMemberResponse type.
- Retrieve
Token Status Response - This is a model struct for RetrieveTokenStatusResponse type
- Retrieve
Wage Setting Response - This is a model struct for RetrieveWageSettingResponse type.
- Retrieve
Webhook Subscription Response - This is a model struct for RetrieveWebhookSubscriptionResponse type
- Revoke
TokenO Auth Request - This is a model struct for RevokeTokenOAuthRequest type.
- Revoke
TokenO Auth Response - This is a model struct for RevokeTokenOAuthResponse type
- Risk
Evaluation - Represents fraud risk information for the associated payment.
- Search
Availability Filter - A query filter to search for buyer-accessible availabilities by.
- Search
Availability Query - The query used to search for buyer-accessible availabilities of bookings.
- Search
Availability Request - This is a model struct for SearchAvailabilityRequest type
- Search
Availability Response - This is a model struct for SearchAvailabilityResponse type
- Search
Catalog Items Request - This is a model struct for SearchCatalogItemsRequest type.
- Search
Catalog Items Response - This is a model struct for SearchCatalogItemsResponse type
- Search
Catalog Objects Request - This is a model struct for SearchCatalogObjectsRequest type.
- Search
Catalog Objects Response - This is a model struct for SearchCatalogObjectsResponse type
- Search
Customer Creation Source Filter - Filter based on order fulfillment information
- Search
Customers Date Time Filter - Filter for
Customerobjects based on whether theirCreatedAttimestamps fall within a specified time range. - Search
Customers Filter - Filtering criteria to use for a
SearchCustomersrequest. - Search
Customers Query - Contains query criteria for the search.
- Search
Customers Request - This is a model struct for SearchCustomersRequest type.
- Search
Customers Response - This is a model struct for SearchCustomersResponse type
- Search
Customers Sort - Sorting criteria for a
SearchCustomersrequest. - Search
Customers Text Filter - Search
Invoices Request - This is a model struct for SearchInvoicesRequest type.
- Search
Invoices Response - This is a model struct for SearchInvoicesResponse type
- Search
Orders Customer Filter - A filter based on the order
customer_idand any tendercustomer_idassociated with the order. - Search
Orders Date Time Filter - Filter for
Orderobjects based on whether theirCreatedAt,CLOSED_AT, orUpdatedAttimestamps fall within a specified time range. - Search
Orders Filter - Filtering criteria to use for a
SearchOrdersrequest. - Search
Orders Fulfillment Filter - Filter based on order fulfillment information
- Search
Orders Query - Contains query criteria for the search.
- Search
Orders Request - This is a model struct for SearchOrdersRequest type.
- Search
Orders Response - This is a model struct for SearchOrdersResponse type
- Search
Orders Sort - Sorting criteria for a
SearchOrdersrequest. - Search
Orders Source Filter - A filter based on order
sourceinformation. - Search
Orders State Filter - Filter by the current order
state. - Search
Subscriptions Filter - Represents a set of query expressions (filters) to narrow the scope of targeted subscriptions returned by the SearchSubscriptions endpoint.
- Search
Subscriptions Query - Represents a query, consisting of specified query expressions, used to search for subscriptions.
- Search
Subscriptions Request - This is a model struct for SearchSubscriptionsRequest type.
- Search
Subscriptions Response - This is a model struct for SearchSubscriptionsResponse type.
- Search
Team Members Filter - Represents a filter used in a search for TeamMember objects.
- Search
Team Members Query - Represents the parameters in a search for
TeamMemberobjects. - Search
Team Members Request - This is a model struct for SearchTeamMembersRequest type.
- Search
Team Members Response - This is a model struct for SearchTeamMembersResponse type.
- Segment
Filter - A query filter to search for buyer-accessible appointment segments by.
- Shipping
Fee - ShippingFee :
- Source
Application - Provides information about the application used to generate a change.
- Square
Account Details - Details about a Square Account payment. The details are only populated if the source_type is SquareAccount.
- Standard
Unit Description - Contains the name and abbreviation for standard measurement unit.
- Standard
Unit Description Group - Group of standard measurement units.
- Subscription
- Represents a subscription to a subscription plan by a subscriber.
- Subscription
Action - Represents an action as a pending change to a subscription.
- Subscription
Event - Describes changes to a subscription and the subscription status.
- Subscription
Event Data - This is a model struct for SubscriptionEventData type.
- Subscription
Event Info - Provides information about the subscription event.
- Subscription
Event Object - This is a model struct for SubscriptionEventObject type.
- Subscription
Event Webhook Response - This is a model struct for SubscriptionEventWebhookResponse type.
- Subscription
Phase - Describes a phase in a subscription plan.
- Subscription
Pricing - Describes the pricing for the subscription.
- Subscription
Source - The origination details of the subscription.
- Subscription
Test Result - /// Subscription test result details.
- Swap
Plan Request - This is a model struct for the SwapPlanRequest type.
- Swap
Plan Response - This is a model struct for the SwapPlanResponse type.
- TaxIds
- Identifiers for the location used by various governments for tax purposes.
- Team
Member - A record representing an individual team member for a business.
- Team
Member Assigned Locations - A record representing an individual team member for a business.
- Team
Member Booking Profile - The booking profile of a seller’s team member, including the team member’s ID, display name, description and whether the team member can be booked as a service provider.
- Team
Member Event Data - This is a model struct for TeamMemberEventData type.
- Team
Member Event Object - This is a model struct for TeamMemberEventObject type.
- Team
Member Event Webhook Response - This is a model struct for TeamMemberEventWebhookResponse type.
- Tender
- Represents a tender (i.e., a method of payment) used in a Square transaction.
- Tender
Bank Account Details - Represents the details of a tender with type BANK_ACCOUNT.
- Tender
BuyNow PayLater Details - Represents the details of a tender with type BUY_NOW_PAY_LATER.
- Tender
Card Details - Represents additional details of a tender with type
CARDorSQUARE_GIFT_CARD - Tender
Cash Details - Represents the details of a tender with
typeCASH. - Tender
Square Account Details - Represents the details of a tender with type SquareAccount.
- Test
Webhook Subscription Request - This is a model struct for TestWebhookSubscriptionRequest type.
- Test
Webhook Subscription Response - This is a model struct for TestWebhookSubscriptionResponse type
- Time
Range - Represents a generic time range.
- Transaction
Deprecated - Represents a transaction processed with Square, either with the Connect API or with Square Point of Sale.
- Unlink
Customer From Gift Card Request - This is a model struct for UnlinkCustomerFromGiftCardRequest type
- Unlink
Customer From Gift Card Response - This is a model struct for UnlinkCustomerFromGiftCardResponse type
- Update
Booking Request - This is a model class for UpdateBookingRequest type.
- Update
Booking Response - This is a model struct for UpdateBookingResponse type.
- Update
Catalog Image Request - This is a model struct for UpdateCatalogImageRequest type.
- Update
Catalog Image Response - This is a model struct for UpdateCatalogImageResponse type.
- Update
Customer Custom Attribute Definition Request - This is a model struct for UpdateCustomerCustomAttributeDefinitionRequest type
- Update
Customer Custom Attribute Definition Response - This is a model struct for UpdateCustomerCustomAttributeDefinitionResponse type
- Update
Customer Group Request - This is a model struct for UpdateCustomerGroupRequest type.
- Update
Customer Group Response - This is a model struct for UpdateCustomerGroupResponse type.
- Update
Customer Request - This is a model struct for UpdateCustomerRequest type.
- Update
Customer Response - This is a model struct for UpdateCustomerResponse type.
- Update
Invoice Request - This is a model struct for UpdateInvoiceRequest type.
- Update
Invoice Response - This is a model struct for UpdateInvoiceResponse type.
- Update
Item Modifier Lists Request - This is a model struct for UpdateItemModifierListsRequest type.
- Update
Item Modifier Lists Response - This is a model struct for UpdateItemModifierListsResponse type.
- Update
Item Taxes Request - This is a model struct for UpdateItemTaxesRequest type.
- Update
Item Taxes Response - This is a model struct for UpdateItemTaxesResponse type.
- Update
JobRequest - This is a model struct for UpdateJobRequest type
- Update
JobResponse - This is a model struct for UpdateJobResponse type
- Update
Location Request - This is a model struct for the UpdateLocationRequest type
- Update
Location Response - This is a model struct for UpdateLocationResponse type
- Update
Location Settings Request - This is a model struct for UpdateLocationSettingsRequest type.
- Update
Location Settings Response - This is a model struct for UpdateLocationSettingsResponse type
- Update
Merchant Settings Request - This is a model struct for UpdateMerchantSettingsRequest type.
- Update
Merchant Settings Response - This is a model struct for UpdateMerchantSettingsResponse type
- Update
Order Request - This is a model struct for UpdateOrderRequest type.
- Update
Order Response - This is a model struct for UpdateOrderResponse type.
- Update
Payment Link Request - This is a model struct for UpdatePaymentLinkRequest type.
- Update
Payment Link Response - This is a model struct for UpdatePaymentLinkResponse type
- Update
Payment Request - This is a model struct for UpdatePaymentRequest type.
- Update
Payment Response - This is a model struct for UpdatePaymentResponse type.
- Update
Subscription Request - This is a model struct for UpdateSubscriptionRequest type.
- Update
Subscription Response - This is a model struct for UpdateSubscriptionResponse type.
- Update
Team Member Request - This is a model struct for UpdateTeamMemberRequest type.
- Update
Team Member Response - This is a model struct for UpdateTeamMemberResponse type.
- Update
Wage Setting Request - This is a model struct for UpdateWageSettingRequest type.
- Update
Wage Setting Response - This is a model struct for UpdateWageSettingResponse type.
- Update
Webhook Subscription Request - This is a model struct for UpdateWebhookSubscriptionRequest type.
- Update
Webhook Subscription Response - This is a model struct for UpdateWebhookSubscriptionResponse type
- Update
Webhook Subscription Signature KeyRequest - This is a model struct for UpdateWebhookSubscriptionSignatureKeyRequest type.
- Update
Webhook Subscription Signature KeyResponse - This is a model struct for UpdateWebhookSubscriptionSignatureKeyResponse type
- Upsert
Catalog Object Request - This is a model struct for UpsertCatalogObjectRequest type.
- Upsert
Catalog Object Response - This is a model struct for UpsertCatalogObjectResponse type.
- Upsert
Customer Custom Attribute Request - Represents the request body for the UpsertCustomerCustomAttribute endpoint.
- Upsert
Customer Custom Attribute Response - Represents the response for the UpsertCustomerCustomAttribute endpoint.
- Wage
Setting - An object representing a team member’s wage information.
- Webhook
Subscription - Represents the details of a webhook subscription, including notification URL, event types, and signature key.