Enums live here
Enums
- AchDetails
Account Type - A type of bank account performing a transfer for payment.
- Application
Details External Square Product - A list of products to return to external callers.
- Archived
State - An enum type of catalog item archived state.
- Bank
Account Payment Details Account Ownership Type - An ownership type of a bank account performing a transfer for payment.
- Bank
Account Payment Details Transfer Type - A type of bank transfer
- Booking
Booking Source - The type of a booking booking
- Booking
Creator Details Creator Type - The type of [Booking] creator
- Booking
Status - The status of a booking
- Booking
Webhook Event Type - The type of booking event coming from the webhook
- Business
Appointment Settings Alignment Time - The time unit of the service duration for bookings.
- Business
Appointment Settings Booking Location Type - The location type of a business, specific to appointments
- Business
Appointment Settings Cancellation Policy - The cancellation policy adopted by the seller.
- Business
Appointment Settings MaxAppointments PerDay Limit Type - Indicates whether the daily appointment limit applies to team members or to business locations.
- Business
Booking Profile Booking Policy - The policy for the seller to automatically accept booking requests (AcceptAll) or not (RequiresAcceptance).
- Business
Booking Profile Customer Timezone Choice - The choice of customer’s time zone information of a booking
- Card
Brand - Indicates a card’s brand, such as
VISAorMASTERCARD. - Card
CoBrand - Indicates a card’s co-brand, such as
AFTERPAYorCLEARPAY. - Card
Payment Details AvsStatus - Status code returned from the Address Verification System (AVS) check.
- Card
Payment Details CvvStatus - Status code returned from the Card Verification Value (CVV) check.
- Card
Payment Details Entry Method - Method used to enter a card’s details for payment.
- Card
Payment Details Status - Card payment state.
- Card
Payment Details Verification Method - Method to verify cardholder’s identity.
- Card
Payment Details Verification Result - Results of cardholder verification.
- Card
Prepaid Type - Indicates a card’s prepaid type, such as
NOT_PREPAIDorPREPAID. - Card
Square Product - Model for CardSquareProduct enum
- Card
Type - Indicates a card’s type, such as
CREDITorDEBIT. - Card
Webhook Event Type - The type of card event coming from the webhook
- Catalog
Category Type - Indicates the type of catalog category.
- Catalog
Custom Attribute Definition AppVisibility - Defines the visibility of a custom attribute to applications other than their creating application.
- Catalog
Custom Attribute Definition Seller Visibility - Defines the visibility of a custom attribute to sellers in Square client applications, Square APIs or in Square UIs (including Square Point of Sale applications and Square Dashboard).
- Catalog
Custom Attribute Definition Type - Defines the possible types for a custom attribute.
- Catalog
Discount Modify TaxBasis - Indicates whether this discount should reduce the price used to calculate tax.
- Catalog
Discount Type - How to apply a CatalogDiscount to a CatalogItem.
- Catalog
Item Food AndBeverage Details Dietary Preference Standard Dietary Preference - The name of the dietary preference from a standard pre-defined list. This should be null if it’s a custom dietary preference.
- Catalog
Item Food AndBeverage Details Dietary Preference Type - The dietary preference type. Supported values include STANDARD and CUSTOM as specified in FoodAndBeverageDetails.DietaryPreferenceType.
- Catalog
Item Food AndBeverage Details Ingredient Standard Ingredient - The name of the ingredient from a standard pre-defined list. This should be null if it’s a custom dietary preference.
- Catalog
Item Product Type - The type of a CatalogItem.
- Catalog
Modifier List Modifier Type - Catalog
Modifier List Selection Type - Indicates whether a CatalogModifierList supports multiple selections.
- Catalog
Object Type - Possible types of CatalogObjects returned from the catalog, each containing type-specific
properties in the
*_datafield corresponding to the specfied object type. - Catalog
Pricing Type - Indicates whether the price of a CatalogItemVariation should be entered manually at the time of sale.
- Catalog
Quick Amount Type - Determines the type of a specific Quick Amount.
- Catalog
Quick Amounts Settings Option - Determines a seller’s option on Quick Amounts feature.
- Catalog
Webhook Event Type - The type of catalog event coming from the webhook
- Change
Timing - Supported timings when a pending change, as an action, takes place to a subscription.
- Checkout
Location Settings Branding Button Shape - Checkout
Location Settings Branding Header Type - Country
- Indicates the country associated with another entity, such as a business.
- Currency
- Indicates the associated currency for an amount of money.
- Custom
Attribute Definition Visibility - Represents the level of permission required to view a custom attribute definition.
- Customer
Creation Source - Indicates the method used to create the customer profile.
- Customer
Inclusion Exclusion - The rule to include or exclude a certain set of values.
- Customer
Webhook Event Type - The type of customer event coming from the webhook
- DayOf
Week - Indicates the specific day of the week.
- Delay
Action - The action to be applied to the payment when the delay_duration has elapsed. The action must be CANCEL or COMPLETE.
- Destination
Details External Refund Details Type - The type of external refund the seller paid to the buyer
- Destination
Type - The destination type for this refund.
- Digital
Wallet Brand - The brand used for the
WALLETpayment. - Error
Category - Indicates which high-level category of error has occurred during a request to the Connect API.
- Error
Code - Indicates which high-level category of error has occurred during a request to the Connect API.
- Exclude
Strategy - Indicates which products matched by a CatalogPricingRule will be excluded if the pricing rule uses an exclude set.
- External
Payment Type - The type of external payment the seller received.
- Gift
Card Activity Redeem Status - Indicates the status of a gift card redemption.
- Gift
Card Activity Type - Indicates the type of the gift card activity.
- Gift
Card Activity Webhook Event Type - The type of gift card activity event coming from the webhook
- Gift
CardGAN Source - Indicates the source that generated the gift card account number (GAN).
- Gift
Card Status - Indicates the gift card state.
- Gift
Card Type - Indicates the gift card type.
- Gift
Card Webhook Event Type - The type of gift card event coming from the webhook
- Grant
Type - An enum type of grant type.
- Inventory
Alert Type - Indicates whether Square should alert the merchant when the inventory quantity of a CatalogItemVariation is low.
- Inventory
Change Type - Indicates how the inventory change is applied.
- Inventory
State - A type of state for the related quantity of items
- Inventory
Webhook Event Type - The type of inventory event coming from the webhook
- Invoice
Automatic Payment Source - Indicates the automatic payment method for an invoice payment request.
- Invoice
Custom Field Placement - Indicates where to render a custom field on the Square-hosted invoice page and in emailed or PDF copies of the invoice.
- Invoice
Delivery Method - Indicates how Square delivers the [Invoice] to the customer.
- Invoice
Payment Reminder Status - The status of a payment request reminder.
- Invoice
Request Method - Invoice
Request Type - Indicates the type of the payment request.
- Invoice
Sort Field - Indicates the status of an invoice.
- Invoice
Status - Indicates the status of an invoice.
- Invoice
Webhook Event Type - The type of invoice event coming from the webhook
- JobAssignment
PayType - Enumerates the possible pay types that a job can be assigned.
- Language
- A language in BCP 47 format. For more information, see Location language code.
- Locale
- Used in OAuth api. The locale to present the permission request form in. Square detects the appropriate locale automatically. Only provide this value if the application can definitively determine the preferred locale.
- Location
Capability - The capabilities a location might have.
- Location
Status - A location’s status.
- Location
Type - A location’s type.
- Location
Webhook Event Type - The type of location event coming from the webhook
- Measurement
Unit Area - Unit of area used to measure a quantity.
- Measurement
Unit Generic - Reserved for API integrations that lack the ability to specify a real measurement unit.
- Measurement
Unit Length - The unit of length used to measure a quantity.
- Measurement
Unit Time - Unit of time used to measure a quantity (a duration).
- Measurement
Unit Unit Type - Describes the type of this unit and indicates which field contains the unit information.
- Measurement
Unit Volume - The unit of volume used to measure a quantity.
- Measurement
Unit Weight - Unit of weight used to measure a quantity.
- OAuth
Permission - Permissions that the application is requesting.
- Oauth
Authorization Revoked Event Revoker Type - The type of revoked event type.
- Oauth
Webhook Event Type - The type of oauth event coming from the webhook
- Online
Checkout Location Settings Event Type - The type of online checkout location settings event coming from the webhook
- Online
Checkout Merchant Settings Event Type - The type of online checkout merchant settings event coming from the webhook
- Order
Event Object - The type of order event data coming from the webhook
- Order
Fulfillment Delivery Details Schedule Type - The schedule type of the delivery fulfillment.
- Order
Fulfillment Fulfillment Line Item Application - The
line_item_applicationdescribes what order line items this fulfillment applies to. - Order
Fulfillment Pickup Details Schedule Type - The schedule type of the pickup fulfillment.
- Order
Fulfillment State - The current state of this fulfillment.
- Order
Fulfillment Type - The type of fulfillment.
- Order
Line Item Discount Scope - Indicates whether this is a line-item or order-level discount.
- Order
Line Item Discount Type - Indicates how the discount is applied to the associated line item or order.
- Order
Line Item Item Type - Represents the line item type.
- Order
Line Item TaxScope - Indicates whether this is a line-item or order-level tax.
- Order
Line Item TaxType - Indicates how the tax is applied to the associated line item or order.
- Order
Service Charge Calculation Phase - Represents a phase in the process of calculating order totals.
- Order
Service Charge Scope - Model for OrderServiceChargeScope enum
- Order
Service Charge Treatment Type - Model for OrderServiceChargeTreatmentType enum
- Order
Service Charge Type - The type of the service charge.
- Order
State - The state of the order.
- Order
Webhook Event Type - The type of order event coming from the webhook
- Payment
Capability - Actions that can be performed on a [Payment]
- Payment
Delay Action - Actions that can be applied to [Payment]s when the
delay_durationhas elapsed. - Payment
Event Payment Event Type - Payment
Refund Status - Indicates a refund’s current status.
- Payment
Sort Field - Indicates a payment’s current status.
- Payment
Source Type - Sources from which [Payment]s can be taken.
- Payment
Status - The status of a [Payment]
- Processing
FeeType - The type of fee assessed or adjusted.
- Product
- Indicates the Square product used to generate an inventory change.
- Refund
Status - Indicates a refund’s current status.
- Refund
Webhook Event Type - The type of refund event coming from the webhook
- Register
Domain Response Status - The status of the domain registration.
- Risk
Evaluation Risk Level - The risk level associated with a payment.
- Search
Catalog Items Request Stock Level - Defines supported stock levels of the item inventory.
- Search
Orders Sort Field - Reserved for API integrations that lack the ability to specify a real measurement unit.
- Sort
Customers Field - Use one or more customer attributes as the sort key to sort searched customer profiles. For example, use the creation date (created_at) of customers or default attributes as the sort key.
- Sort
Order - The order (e.g., chronological or alphabetical) in which results from a request are returned.
- Subscription
Action Type - Supported types of an action as a pending change to a subscription.
- Subscription
Cadence - Determines the billing cadence of a [Subscription]
- Subscription
Event Info Code - Supported info codes of a subscription event.
- Subscription
Event Subscription Event Type - Supported types of an event occurred to a subscription.
- Subscription
Pricing Type - Supported types of a subscription pricing.
- Subscription
Status - Supported subscription statuses.
- Subscription
Webhook Event Type - The type of subscription event coming from the webhook
- TaxCalculation
Phase - When to calculate the taxes due on a cart.
- TaxInclusion
Type - Whether to the tax amount should be additional to or included in the CatalogItem price.
- Team
Member Assigned Locations Assignment Type - Enumerates the possible assignment types that the team member can have.
- Team
Member Status - Enumerates the possible statuses the team member can have within a business.
- Team
Member Webhook Event Type - The type of team member event coming from the webhook
- Tender
Bank Account Details Status - The bank account payment’s current state.
- Tender
BuyNow PayLater Details Brand - The Buy Now Pay Later brand.
- Tender
BuyNow PayLater Details Status - Model for TenderBuyNowPayLaterDetailsStatus enum.
- Tender
Card Details Entry Method - Indicates the method used to enter the card’s details.
- Tender
Card Details Status - Indicates the card transaction’s current status.
- Tender
Square Account Details Status - Model for TenderSquareAccountDetailsStatus enum.
- Tender
Type - Indicates a tender’s type.
- Timezone
- An IANA time zone identifier for a time zone.
- Transaction
Product - Indicates the Square product used to process a transaction.
- Webhook
Event Type - The types of webhook events