pub struct CatalogCategory {
pub name: Option<String>,
pub image_ids: Option<Vec<String>>,
pub category_type: Option<CatalogCategoryType>,
pub parent_category: Option<CatalogObjectCategory>,
pub is_top_level: Option<bool>,
pub channels: Option<Vec<String>>,
pub availability_period_ids: Option<Vec<String>>,
pub online_visibility: Option<bool>,
pub root_category: Option<String>,
pub ecom_seo_data: Option<CatalogEcomSeoData>,
pub path_to_root: Option<Vec<CategoryPathToRootNode>>,
}Expand description
A category to which a CatalogItem instance belongs.
Fields
name: Option<String>The category name. This is a searchable attribute for use in applicable query filters, and its value length is of Unicode code points.
image_ids: Option<Vec<String>>The IDs of images associated with this CatalogCategory instance. Currently these images
are not displayed by Square, but are free to be displayed in 3rd party applications.
category_type: Option<CatalogCategoryType>The type of the category.
parent_category: Option<CatalogObjectCategory>The ID of the parent category of this category instance.
is_top_level: Option<bool>Indicates whether a category is a top level category, which does not have any parent_category.
channels: Option<Vec<String>>A list of IDs representing channels, such as a Square Online site, where the category can be made visible.
availability_period_ids: Option<Vec<String>>The IDs of the CatalogAvailabilityPeriod objects associated with the category.
online_visibility: Option<bool>Indicates whether the category is visible (true) or hidden (false) on all of the seller’s Square Online sites.
root_category: Option<String>Read only The top-level category in a category hierarchy.
ecom_seo_data: Option<CatalogEcomSeoData>The SEO data for a seller’s Square Online store.
path_to_root: Option<Vec<CategoryPathToRootNode>>The path from the category to its root category. The first node of the path is the parent of the category and the last is the root category. The path is empty if the category is a root category.