pub struct InventoryCount {
pub calculated_at: String,
pub catalog_object_id: String,
pub catalog_object_type: String,
pub is_estimated: Option<bool>,
pub location_id: String,
pub quantity: String,
pub state: InventoryState,
}Expand description
The current calculated inventory counts for the requested object and locations.
Fields
calculated_at: StringRead only An RFC 3339-formatted timestamp that indicates when the most recent physical count or adjustment affecting the estimated count is received.
catalog_object_id: StringThe Square-generated ID of the CatalogObject being tracked.
catalog_object_type: StringThe type of the CatalogObject being tracked. The Inventory API supports setting and reading the “catalog_object_type”: “ITEM_VARIATION” In addition, it can also read the “catalog_object_type”: “ITEM”
is_estimated: Option<bool>Read only Whether the inventory count is for composed variation (TRUE) or not (FALSE).
location_id: StringThe Square-generated ID of the Location where the related quantity of items is being tracked.
quantity: StringThe number of items affected by the estimated count as a decimal string.
state: InventoryStateThe current inventory state for the related quantity of items.