pub struct ListJobsParameters {
pub cursor: Option<String>,
}Expand description
This is a model struct for ListJobsParameters (query parameters)
Fields
cursor: Option<String>The pagination cursor returned by the previous call to this endpoint. Provide this cursor to retrieve the next page of results for your original request.
Implementations
Sourceimpl ListJobsParameters
impl ListJobsParameters
Sourcepub fn to_query_string(&self) -> String
pub fn to_query_string(&self) -> String
Converts the struct to a query string.